# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class TaxWithheldComponent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'tax_collection_model': 'str',
        'taxes_withheld': 'ChargeComponentList'
    }

    attribute_map = {
        'tax_collection_model': 'TaxCollectionModel',
        'taxes_withheld': 'TaxesWithheld'
    }

    def __init__(self, tax_collection_model=None, taxes_withheld=None):  # noqa: E501
        """TaxWithheldComponent - a model defined in Swagger"""  # noqa: E501
        self._tax_collection_model = None
        self._taxes_withheld = None
        self.discriminator = None
        if tax_collection_model is not None:
            self.tax_collection_model = tax_collection_model
        if taxes_withheld is not None:
            self.taxes_withheld = taxes_withheld

    @property
    def tax_collection_model(self):
        """Gets the tax_collection_model of this TaxWithheldComponent.  # noqa: E501

        The tax collection model applied to the item.  Possible values:  * MarketplaceFacilitator - Tax is withheld and remitted to the taxing authority by Amazon on behalf of the seller.  * Standard - Tax is paid to the seller and not remitted to the taxing authority by Amazon.  # noqa: E501

        :return: The tax_collection_model of this TaxWithheldComponent.  # noqa: E501
        :rtype: str
        """
        return self._tax_collection_model

    @tax_collection_model.setter
    def tax_collection_model(self, tax_collection_model):
        """Sets the tax_collection_model of this TaxWithheldComponent.

        The tax collection model applied to the item.  Possible values:  * MarketplaceFacilitator - Tax is withheld and remitted to the taxing authority by Amazon on behalf of the seller.  * Standard - Tax is paid to the seller and not remitted to the taxing authority by Amazon.  # noqa: E501

        :param tax_collection_model: The tax_collection_model of this TaxWithheldComponent.  # noqa: E501
        :type: str
        """

        self._tax_collection_model = tax_collection_model

    @property
    def taxes_withheld(self):
        """Gets the taxes_withheld of this TaxWithheldComponent.  # noqa: E501


        :return: The taxes_withheld of this TaxWithheldComponent.  # noqa: E501
        :rtype: ChargeComponentList
        """
        return self._taxes_withheld

    @taxes_withheld.setter
    def taxes_withheld(self, taxes_withheld):
        """Sets the taxes_withheld of this TaxWithheldComponent.


        :param taxes_withheld: The taxes_withheld of this TaxWithheldComponent.  # noqa: E501
        :type: ChargeComponentList
        """

        self._taxes_withheld = taxes_withheld

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TaxWithheldComponent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaxWithheldComponent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from datetime import datetime

from sp_api.api.sales.models.get_order_metrics_response import GetOrderMetricsResponse
from sp_api.base import Client, Marketplaces, sp_endpoint, Granularity
import logging
logging.basicConfig(level=logging.DEBUG)


class Sales(Client):
    def __init__(self, marketplace=Marketplaces.US, refresh_token=None):
        super().__init__(marketplace, refresh_token)

    @sp_endpoint('/sales/v1/orderMetrics')
    def get_order_metrics(self, interval: tuple, granularity: Granularity, granularityTimeZone: str = None, **kwargs):
        """
        DOCS: https://github.com/amzn/selling-partner-api-docs/blob/main/references/sales-api/sales.md#parameters

        Returns aggregated order metrics for given interval, broken down by granularity, for given buyer type.

        **Usage Plan:**

        | Rate (requests per second) | Burst |
        | ---- | ---- |
        | .5 | 15 |

        For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.

        Type	Name	Description	Schema	Default
        Query	marketplaceIds
        required

        A list of marketplace identifiers. Example: ATVPDKIKX0DER indicates the US marketplace.	< string > array	-

        Query	interval
        required

        A time interval used for selecting order metrics.
        This takes the form of two dates separated by two hyphens (first date is inclusive; second date is exclusive).
        Dates are in ISO8601 format and must represent absolute time (either Z notation or offset notation).
        Example: 2018-09-01T00:00:00-07:00--2018-09-04T00:00:00-07:00 requests order metrics for Sept 1st, 2nd and 3rd in the -07:00 zone.	string	-

        Query	granularityTimeZone
        optional

        An IANA-compatible time zone for determining the day boundary.
        !! Required when specifying a granularity value greater than Hour. !!
        The granularityTimeZone value must align with the offset of the specified interval value.
        For example, if the interval value uses Z notation, then granularityTimeZone must be UTC.
        If the interval value uses an offset, then granularityTimeZone must be an IANA-compatible time zone that matches the offset.
        Example: US/Pacific to compute day boundaries, accounting for daylight time savings, for US/Pacific zone.	string	-

        Query	granularity
        required

        The granularity of the grouping of order metrics, based on a unit of time.
        Specifying granularity=Hour results in a successful request only if the interval specified is less than or equal to 30 days from now.
        For all other granularities, the interval specified must be less or equal to 2 years from now.
        Specifying granularity=Total results in order metrics that are aggregated over the entire interval that you specify.
        If the interval start and end date don’t align with the specified granularity, the head and tail end of the response interval will contain partial data.
        Example: Day to get a daily breakdown of the request interval, where the day boundary is defined by the granularityTimeZone.	enum (Granularity)	-

        Query	buyerType
        optional

        Filters the results by the buyer type that you specify, B2B (business to business) or B2C (business to customer).
        Example: B2B, if you want the response to include order metrics for only B2B buyers.
        Default: enum (BuyerType)	"All"

        Query	fulfillmentNetwork
        optional

        Filters the results by the fulfillment network that you specify,
        MFN (merchant fulfillment network) or AFN (Amazon fulfillment network).
        Do not include this filter if you want the response to include order metrics for all fulfillment networks.
        Example: AFN, if you want the response to include order metrics for only Amazon fulfillment network.	string -

        Query	firstDayOfWeek
        optional

        Specifies the day that the week starts on when granularity=Week, either Monday or Sunday.
        Default: Monday.
        Example: Sunday, if you want the week to start on a Sunday.	enum (FirstDayOfWeek)	"Monday"

        Query	asin
        optional

        Filters the results by the ASIN that you specify. Specifying both ASIN and SKU returns an error.
        Do not include this filter if you want the response to include order metrics for all ASINs.
        Example: B0792R1RSN, if you want the response to include order metrics for only ASIN B0792R1RSN.	string	-

        Query	sku
        optional

        Filters the results by the SKU that you specify.
        Specifying both ASIN and SKU returns an error.
        Do not include this filter if you want the response to include order metrics for all SKUs. Example: TestSKU, if you want the response to include order metrics for only SKU TestSKU.

        :param interval:
        :param granularityTimeZone:
        :param granularity:
        :param kwargs:
        :return:
        """
        kwargs.update({
            'interval': '--'.join([self._create_datetime_stamp(_interval) for _interval in interval]),
            'granularity': granularity.value.upper(),
        })
        if granularityTimeZone:
            kwargs.update({'granularityTimeZone': granularityTimeZone})
        return GetOrderMetricsResponse(**self._request(kwargs.pop('path'), params=kwargs).json())

    @staticmethod
    def _create_datetime_stamp(datetime_obj: datetime or str):
        if isinstance(datetime_obj, str):
            return datetime_obj
        fmt = '%Y-%m-%dT%H:%M:%S%z'
        return datetime_obj.strftime(fmt)[:-2] + ':00'



# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class SAFETReimbursementEvent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'posted_date': 'ModelDate',
        'safet_claim_id': 'str',
        'reimbursed_amount': 'Currency',
        'reason_code': 'str',
        'safet_reimbursement_item_list': 'SAFETReimbursementItemList'
    }

    attribute_map = {
        'posted_date': 'PostedDate',
        'safet_claim_id': 'SAFETClaimId',
        'reimbursed_amount': 'ReimbursedAmount',
        'reason_code': 'ReasonCode',
        'safet_reimbursement_item_list': 'SAFETReimbursementItemList'
    }

    def __init__(self, posted_date=None, safet_claim_id=None, reimbursed_amount=None, reason_code=None, safet_reimbursement_item_list=None):  # noqa: E501
        """SAFETReimbursementEvent - a model defined in Swagger"""  # noqa: E501
        self._posted_date = None
        self._safet_claim_id = None
        self._reimbursed_amount = None
        self._reason_code = None
        self._safet_reimbursement_item_list = None
        self.discriminator = None
        if posted_date is not None:
            self.posted_date = posted_date
        if safet_claim_id is not None:
            self.safet_claim_id = safet_claim_id
        if reimbursed_amount is not None:
            self.reimbursed_amount = reimbursed_amount
        if reason_code is not None:
            self.reason_code = reason_code
        if safet_reimbursement_item_list is not None:
            self.safet_reimbursement_item_list = safet_reimbursement_item_list

    @property
    def posted_date(self):
        """Gets the posted_date of this SAFETReimbursementEvent.  # noqa: E501


        :return: The posted_date of this SAFETReimbursementEvent.  # noqa: E501
        :rtype: ModelDate
        """
        return self._posted_date

    @posted_date.setter
    def posted_date(self, posted_date):
        """Sets the posted_date of this SAFETReimbursementEvent.


        :param posted_date: The posted_date of this SAFETReimbursementEvent.  # noqa: E501
        :type: ModelDate
        """

        self._posted_date = posted_date

    @property
    def safet_claim_id(self):
        """Gets the safet_claim_id of this SAFETReimbursementEvent.  # noqa: E501

        A SAFE-T claim identifier.  # noqa: E501

        :return: The safet_claim_id of this SAFETReimbursementEvent.  # noqa: E501
        :rtype: str
        """
        return self._safet_claim_id

    @safet_claim_id.setter
    def safet_claim_id(self, safet_claim_id):
        """Sets the safet_claim_id of this SAFETReimbursementEvent.

        A SAFE-T claim identifier.  # noqa: E501

        :param safet_claim_id: The safet_claim_id of this SAFETReimbursementEvent.  # noqa: E501
        :type: str
        """

        self._safet_claim_id = safet_claim_id

    @property
    def reimbursed_amount(self):
        """Gets the reimbursed_amount of this SAFETReimbursementEvent.  # noqa: E501


        :return: The reimbursed_amount of this SAFETReimbursementEvent.  # noqa: E501
        :rtype: Currency
        """
        return self._reimbursed_amount

    @reimbursed_amount.setter
    def reimbursed_amount(self, reimbursed_amount):
        """Sets the reimbursed_amount of this SAFETReimbursementEvent.


        :param reimbursed_amount: The reimbursed_amount of this SAFETReimbursementEvent.  # noqa: E501
        :type: Currency
        """

        self._reimbursed_amount = reimbursed_amount

    @property
    def reason_code(self):
        """Gets the reason_code of this SAFETReimbursementEvent.  # noqa: E501

        Indicates why the seller was reimbursed.  # noqa: E501

        :return: The reason_code of this SAFETReimbursementEvent.  # noqa: E501
        :rtype: str
        """
        return self._reason_code

    @reason_code.setter
    def reason_code(self, reason_code):
        """Sets the reason_code of this SAFETReimbursementEvent.

        Indicates why the seller was reimbursed.  # noqa: E501

        :param reason_code: The reason_code of this SAFETReimbursementEvent.  # noqa: E501
        :type: str
        """

        self._reason_code = reason_code

    @property
    def safet_reimbursement_item_list(self):
        """Gets the safet_reimbursement_item_list of this SAFETReimbursementEvent.  # noqa: E501


        :return: The safet_reimbursement_item_list of this SAFETReimbursementEvent.  # noqa: E501
        :rtype: SAFETReimbursementItemList
        """
        return self._safet_reimbursement_item_list

    @safet_reimbursement_item_list.setter
    def safet_reimbursement_item_list(self, safet_reimbursement_item_list):
        """Sets the safet_reimbursement_item_list of this SAFETReimbursementEvent.


        :param safet_reimbursement_item_list: The safet_reimbursement_item_list of this SAFETReimbursementEvent.  # noqa: E501
        :type: SAFETReimbursementItemList
        """

        self._safet_reimbursement_item_list = safet_reimbursement_item_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SAFETReimbursementEvent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SAFETReimbursementEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Sellers

    The Selling Partner API for Sellers lets you retrieve information on behalf of sellers about their seller account, such as the marketplaces they participate in. Along with listing the marketplaces that a seller can sell in, the API also provides additional information about the marketplace such as the default language and the default currency. The API also provides seller-specific information such as whether the seller has suspended listings in that marketplace.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Participation(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_participating': 'bool',
        'has_suspended_listings': 'bool'
    }

    attribute_map = {
        'is_participating': 'isParticipating',
        'has_suspended_listings': 'hasSuspendedListings'
    }

    def __init__(self, is_participating=None, has_suspended_listings=None):  # noqa: E501
        """Participation - a model defined in Swagger"""  # noqa: E501
        self._is_participating = None
        self._has_suspended_listings = None
        self.discriminator = None
        self.is_participating = is_participating
        self.has_suspended_listings = has_suspended_listings

    @property
    def is_participating(self):
        """Gets the is_participating of this Participation.  # noqa: E501


        :return: The is_participating of this Participation.  # noqa: E501
        :rtype: bool
        """
        return self._is_participating

    @is_participating.setter
    def is_participating(self, is_participating):
        """Sets the is_participating of this Participation.


        :param is_participating: The is_participating of this Participation.  # noqa: E501
        :type: bool
        """
        if is_participating is None:
            raise ValueError("Invalid value for `is_participating`, must not be `None`")  # noqa: E501

        self._is_participating = is_participating

    @property
    def has_suspended_listings(self):
        """Gets the has_suspended_listings of this Participation.  # noqa: E501

        Specifies if the seller has suspended listings. True if the seller Listing Status is set to Inactive, otherwise False.  # noqa: E501

        :return: The has_suspended_listings of this Participation.  # noqa: E501
        :rtype: bool
        """
        return self._has_suspended_listings

    @has_suspended_listings.setter
    def has_suspended_listings(self, has_suspended_listings):
        """Sets the has_suspended_listings of this Participation.

        Specifies if the seller has suspended listings. True if the seller Listing Status is set to Inactive, otherwise False.  # noqa: E501

        :param has_suspended_listings: The has_suspended_listings of this Participation.  # noqa: E501
        :type: bool
        """
        if has_suspended_listings is None:
            raise ValueError("Invalid value for `has_suspended_listings`, must not be `None`")  # noqa: E501

        self._has_suspended_listings = has_suspended_listings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Participation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Participation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ShipmentEvent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amazon_order_id': 'str',
        'seller_order_id': 'str',
        'marketplace_name': 'str',
        'order_charge_list': 'ChargeComponentList',
        'order_charge_adjustment_list': 'ChargeComponentList',
        'shipment_fee_list': 'FeeComponentList',
        'shipment_fee_adjustment_list': 'FeeComponentList',
        'order_fee_list': 'FeeComponentList',
        'order_fee_adjustment_list': 'FeeComponentList',
        'direct_payment_list': 'DirectPaymentList',
        'posted_date': 'ModelDate',
        'shipment_item_list': 'ShipmentItemList',
        'shipment_item_adjustment_list': 'ShipmentItemList'
    }

    attribute_map = {
        'amazon_order_id': 'AmazonOrderId',
        'seller_order_id': 'SellerOrderId',
        'marketplace_name': 'MarketplaceName',
        'order_charge_list': 'OrderChargeList',
        'order_charge_adjustment_list': 'OrderChargeAdjustmentList',
        'shipment_fee_list': 'ShipmentFeeList',
        'shipment_fee_adjustment_list': 'ShipmentFeeAdjustmentList',
        'order_fee_list': 'OrderFeeList',
        'order_fee_adjustment_list': 'OrderFeeAdjustmentList',
        'direct_payment_list': 'DirectPaymentList',
        'posted_date': 'PostedDate',
        'shipment_item_list': 'ShipmentItemList',
        'shipment_item_adjustment_list': 'ShipmentItemAdjustmentList'
    }

    def __init__(self, amazon_order_id=None, seller_order_id=None, marketplace_name=None, order_charge_list=None, order_charge_adjustment_list=None, shipment_fee_list=None, shipment_fee_adjustment_list=None, order_fee_list=None, order_fee_adjustment_list=None, direct_payment_list=None, posted_date=None, shipment_item_list=None, shipment_item_adjustment_list=None):  # noqa: E501
        """ShipmentEvent - a model defined in Swagger"""  # noqa: E501
        self._amazon_order_id = None
        self._seller_order_id = None
        self._marketplace_name = None
        self._order_charge_list = None
        self._order_charge_adjustment_list = None
        self._shipment_fee_list = None
        self._shipment_fee_adjustment_list = None
        self._order_fee_list = None
        self._order_fee_adjustment_list = None
        self._direct_payment_list = None
        self._posted_date = None
        self._shipment_item_list = None
        self._shipment_item_adjustment_list = None
        self.discriminator = None
        if amazon_order_id is not None:
            self.amazon_order_id = amazon_order_id
        if seller_order_id is not None:
            self.seller_order_id = seller_order_id
        if marketplace_name is not None:
            self.marketplace_name = marketplace_name
        if order_charge_list is not None:
            self.order_charge_list = order_charge_list
        if order_charge_adjustment_list is not None:
            self.order_charge_adjustment_list = order_charge_adjustment_list
        if shipment_fee_list is not None:
            self.shipment_fee_list = shipment_fee_list
        if shipment_fee_adjustment_list is not None:
            self.shipment_fee_adjustment_list = shipment_fee_adjustment_list
        if order_fee_list is not None:
            self.order_fee_list = order_fee_list
        if order_fee_adjustment_list is not None:
            self.order_fee_adjustment_list = order_fee_adjustment_list
        if direct_payment_list is not None:
            self.direct_payment_list = direct_payment_list
        if posted_date is not None:
            self.posted_date = posted_date
        if shipment_item_list is not None:
            self.shipment_item_list = shipment_item_list
        if shipment_item_adjustment_list is not None:
            self.shipment_item_adjustment_list = shipment_item_adjustment_list

    @property
    def amazon_order_id(self):
        """Gets the amazon_order_id of this ShipmentEvent.  # noqa: E501

        An Amazon-defined identifier for an order.  # noqa: E501

        :return: The amazon_order_id of this ShipmentEvent.  # noqa: E501
        :rtype: str
        """
        return self._amazon_order_id

    @amazon_order_id.setter
    def amazon_order_id(self, amazon_order_id):
        """Sets the amazon_order_id of this ShipmentEvent.

        An Amazon-defined identifier for an order.  # noqa: E501

        :param amazon_order_id: The amazon_order_id of this ShipmentEvent.  # noqa: E501
        :type: str
        """

        self._amazon_order_id = amazon_order_id

    @property
    def seller_order_id(self):
        """Gets the seller_order_id of this ShipmentEvent.  # noqa: E501

        A seller-defined identifier for an order.  # noqa: E501

        :return: The seller_order_id of this ShipmentEvent.  # noqa: E501
        :rtype: str
        """
        return self._seller_order_id

    @seller_order_id.setter
    def seller_order_id(self, seller_order_id):
        """Sets the seller_order_id of this ShipmentEvent.

        A seller-defined identifier for an order.  # noqa: E501

        :param seller_order_id: The seller_order_id of this ShipmentEvent.  # noqa: E501
        :type: str
        """

        self._seller_order_id = seller_order_id

    @property
    def marketplace_name(self):
        """Gets the marketplace_name of this ShipmentEvent.  # noqa: E501

        The name of the marketplace where the event occurred.  # noqa: E501

        :return: The marketplace_name of this ShipmentEvent.  # noqa: E501
        :rtype: str
        """
        return self._marketplace_name

    @marketplace_name.setter
    def marketplace_name(self, marketplace_name):
        """Sets the marketplace_name of this ShipmentEvent.

        The name of the marketplace where the event occurred.  # noqa: E501

        :param marketplace_name: The marketplace_name of this ShipmentEvent.  # noqa: E501
        :type: str
        """

        self._marketplace_name = marketplace_name

    @property
    def order_charge_list(self):
        """Gets the order_charge_list of this ShipmentEvent.  # noqa: E501


        :return: The order_charge_list of this ShipmentEvent.  # noqa: E501
        :rtype: ChargeComponentList
        """
        return self._order_charge_list

    @order_charge_list.setter
    def order_charge_list(self, order_charge_list):
        """Sets the order_charge_list of this ShipmentEvent.


        :param order_charge_list: The order_charge_list of this ShipmentEvent.  # noqa: E501
        :type: ChargeComponentList
        """

        self._order_charge_list = order_charge_list

    @property
    def order_charge_adjustment_list(self):
        """Gets the order_charge_adjustment_list of this ShipmentEvent.  # noqa: E501


        :return: The order_charge_adjustment_list of this ShipmentEvent.  # noqa: E501
        :rtype: ChargeComponentList
        """
        return self._order_charge_adjustment_list

    @order_charge_adjustment_list.setter
    def order_charge_adjustment_list(self, order_charge_adjustment_list):
        """Sets the order_charge_adjustment_list of this ShipmentEvent.


        :param order_charge_adjustment_list: The order_charge_adjustment_list of this ShipmentEvent.  # noqa: E501
        :type: ChargeComponentList
        """

        self._order_charge_adjustment_list = order_charge_adjustment_list

    @property
    def shipment_fee_list(self):
        """Gets the shipment_fee_list of this ShipmentEvent.  # noqa: E501


        :return: The shipment_fee_list of this ShipmentEvent.  # noqa: E501
        :rtype: FeeComponentList
        """
        return self._shipment_fee_list

    @shipment_fee_list.setter
    def shipment_fee_list(self, shipment_fee_list):
        """Sets the shipment_fee_list of this ShipmentEvent.


        :param shipment_fee_list: The shipment_fee_list of this ShipmentEvent.  # noqa: E501
        :type: FeeComponentList
        """

        self._shipment_fee_list = shipment_fee_list

    @property
    def shipment_fee_adjustment_list(self):
        """Gets the shipment_fee_adjustment_list of this ShipmentEvent.  # noqa: E501


        :return: The shipment_fee_adjustment_list of this ShipmentEvent.  # noqa: E501
        :rtype: FeeComponentList
        """
        return self._shipment_fee_adjustment_list

    @shipment_fee_adjustment_list.setter
    def shipment_fee_adjustment_list(self, shipment_fee_adjustment_list):
        """Sets the shipment_fee_adjustment_list of this ShipmentEvent.


        :param shipment_fee_adjustment_list: The shipment_fee_adjustment_list of this ShipmentEvent.  # noqa: E501
        :type: FeeComponentList
        """

        self._shipment_fee_adjustment_list = shipment_fee_adjustment_list

    @property
    def order_fee_list(self):
        """Gets the order_fee_list of this ShipmentEvent.  # noqa: E501


        :return: The order_fee_list of this ShipmentEvent.  # noqa: E501
        :rtype: FeeComponentList
        """
        return self._order_fee_list

    @order_fee_list.setter
    def order_fee_list(self, order_fee_list):
        """Sets the order_fee_list of this ShipmentEvent.


        :param order_fee_list: The order_fee_list of this ShipmentEvent.  # noqa: E501
        :type: FeeComponentList
        """

        self._order_fee_list = order_fee_list

    @property
    def order_fee_adjustment_list(self):
        """Gets the order_fee_adjustment_list of this ShipmentEvent.  # noqa: E501


        :return: The order_fee_adjustment_list of this ShipmentEvent.  # noqa: E501
        :rtype: FeeComponentList
        """
        return self._order_fee_adjustment_list

    @order_fee_adjustment_list.setter
    def order_fee_adjustment_list(self, order_fee_adjustment_list):
        """Sets the order_fee_adjustment_list of this ShipmentEvent.


        :param order_fee_adjustment_list: The order_fee_adjustment_list of this ShipmentEvent.  # noqa: E501
        :type: FeeComponentList
        """

        self._order_fee_adjustment_list = order_fee_adjustment_list

    @property
    def direct_payment_list(self):
        """Gets the direct_payment_list of this ShipmentEvent.  # noqa: E501


        :return: The direct_payment_list of this ShipmentEvent.  # noqa: E501
        :rtype: DirectPaymentList
        """
        return self._direct_payment_list

    @direct_payment_list.setter
    def direct_payment_list(self, direct_payment_list):
        """Sets the direct_payment_list of this ShipmentEvent.


        :param direct_payment_list: The direct_payment_list of this ShipmentEvent.  # noqa: E501
        :type: DirectPaymentList
        """

        self._direct_payment_list = direct_payment_list

    @property
    def posted_date(self):
        """Gets the posted_date of this ShipmentEvent.  # noqa: E501


        :return: The posted_date of this ShipmentEvent.  # noqa: E501
        :rtype: ModelDate
        """
        return self._posted_date

    @posted_date.setter
    def posted_date(self, posted_date):
        """Sets the posted_date of this ShipmentEvent.


        :param posted_date: The posted_date of this ShipmentEvent.  # noqa: E501
        :type: ModelDate
        """

        self._posted_date = posted_date

    @property
    def shipment_item_list(self):
        """Gets the shipment_item_list of this ShipmentEvent.  # noqa: E501


        :return: The shipment_item_list of this ShipmentEvent.  # noqa: E501
        :rtype: ShipmentItemList
        """
        return self._shipment_item_list

    @shipment_item_list.setter
    def shipment_item_list(self, shipment_item_list):
        """Sets the shipment_item_list of this ShipmentEvent.


        :param shipment_item_list: The shipment_item_list of this ShipmentEvent.  # noqa: E501
        :type: ShipmentItemList
        """

        self._shipment_item_list = shipment_item_list

    @property
    def shipment_item_adjustment_list(self):
        """Gets the shipment_item_adjustment_list of this ShipmentEvent.  # noqa: E501


        :return: The shipment_item_adjustment_list of this ShipmentEvent.  # noqa: E501
        :rtype: ShipmentItemList
        """
        return self._shipment_item_adjustment_list

    @shipment_item_adjustment_list.setter
    def shipment_item_adjustment_list(self, shipment_item_adjustment_list):
        """Sets the shipment_item_adjustment_list of this ShipmentEvent.


        :param shipment_item_adjustment_list: The shipment_item_adjustment_list of this ShipmentEvent.  # noqa: E501
        :type: ShipmentItemList
        """

        self._shipment_item_adjustment_list = shipment_item_adjustment_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ShipmentEvent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShipmentEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Orders

    The Selling Partner API for Orders helps you programmatically retrieve order information. These APIs let you develop fast, flexible, custom applications in areas like order synchronization, order research, and demand-based decision support tools.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from models.order_item_list import OrderItemList  # noqa: E501
from swagger_client.rest import ApiException


class TestOrderItemList(unittest.TestCase):
    """OrderItemList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOrderItemList(self):
        """Test OrderItemList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.order_item_list.OrderItemList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Selling Partner API for Product Fees

    The Selling Partner API for Product Fees lets you programmatically retrieve estimated fees for a product. You can then account for those fees in your pricing.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class FeesEstimateIdentifier(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'marketplace_id': 'str',
        'seller_id': 'str',
        'id_type': 'str',
        'id_value': 'str',
        'is_amazon_fulfilled': 'bool',
        'price_to_estimate_fees': 'PriceToEstimateFees',
        'seller_input_identifier': 'str'
    }

    attribute_map = {
        'marketplace_id': 'MarketplaceId',
        'seller_id': 'SellerId',
        'id_type': 'IdType',
        'id_value': 'IdValue',
        'is_amazon_fulfilled': 'IsAmazonFulfilled',
        'price_to_estimate_fees': 'PriceToEstimateFees',
        'seller_input_identifier': 'SellerInputIdentifier'
    }

    def __init__(self, marketplace_id=None, seller_id=None, id_type=None, id_value=None, is_amazon_fulfilled=None, price_to_estimate_fees=None, seller_input_identifier=None):  # noqa: E501
        """FeesEstimateIdentifier - a model defined in Swagger"""  # noqa: E501
        self._marketplace_id = None
        self._seller_id = None
        self._id_type = None
        self._id_value = None
        self._is_amazon_fulfilled = None
        self._price_to_estimate_fees = None
        self._seller_input_identifier = None
        self.discriminator = None
        if marketplace_id is not None:
            self.marketplace_id = marketplace_id
        if seller_id is not None:
            self.seller_id = seller_id
        if id_type is not None:
            self.id_type = id_type
        if id_value is not None:
            self.id_value = id_value
        if is_amazon_fulfilled is not None:
            self.is_amazon_fulfilled = is_amazon_fulfilled
        if price_to_estimate_fees is not None:
            self.price_to_estimate_fees = price_to_estimate_fees
        if seller_input_identifier is not None:
            self.seller_input_identifier = seller_input_identifier

    @property
    def marketplace_id(self):
        """Gets the marketplace_id of this FeesEstimateIdentifier.  # noqa: E501

        A marketplace identifier.  # noqa: E501

        :return: The marketplace_id of this FeesEstimateIdentifier.  # noqa: E501
        :rtype: str
        """
        return self._marketplace_id

    @marketplace_id.setter
    def marketplace_id(self, marketplace_id):
        """Sets the marketplace_id of this FeesEstimateIdentifier.

        A marketplace identifier.  # noqa: E501

        :param marketplace_id: The marketplace_id of this FeesEstimateIdentifier.  # noqa: E501
        :type: str
        """

        self._marketplace_id = marketplace_id

    @property
    def seller_id(self):
        """Gets the seller_id of this FeesEstimateIdentifier.  # noqa: E501

        The seller identifier.  # noqa: E501

        :return: The seller_id of this FeesEstimateIdentifier.  # noqa: E501
        :rtype: str
        """
        return self._seller_id

    @seller_id.setter
    def seller_id(self, seller_id):
        """Sets the seller_id of this FeesEstimateIdentifier.

        The seller identifier.  # noqa: E501

        :param seller_id: The seller_id of this FeesEstimateIdentifier.  # noqa: E501
        :type: str
        """

        self._seller_id = seller_id

    @property
    def id_type(self):
        """Gets the id_type of this FeesEstimateIdentifier.  # noqa: E501

        The type of item identifier specified.  # noqa: E501

        :return: The id_type of this FeesEstimateIdentifier.  # noqa: E501
        :rtype: str
        """
        return self._id_type

    @id_type.setter
    def id_type(self, id_type):
        """Sets the id_type of this FeesEstimateIdentifier.

        The type of item identifier specified.  # noqa: E501

        :param id_type: The id_type of this FeesEstimateIdentifier.  # noqa: E501
        :type: str
        """

        self._id_type = id_type

    @property
    def id_value(self):
        """Gets the id_value of this FeesEstimateIdentifier.  # noqa: E501

        The item identifier.  # noqa: E501

        :return: The id_value of this FeesEstimateIdentifier.  # noqa: E501
        :rtype: str
        """
        return self._id_value

    @id_value.setter
    def id_value(self, id_value):
        """Sets the id_value of this FeesEstimateIdentifier.

        The item identifier.  # noqa: E501

        :param id_value: The id_value of this FeesEstimateIdentifier.  # noqa: E501
        :type: str
        """

        self._id_value = id_value

    @property
    def is_amazon_fulfilled(self):
        """Gets the is_amazon_fulfilled of this FeesEstimateIdentifier.  # noqa: E501

        When true, the offer is fulfilled by Amazon.  # noqa: E501

        :return: The is_amazon_fulfilled of this FeesEstimateIdentifier.  # noqa: E501
        :rtype: bool
        """
        return self._is_amazon_fulfilled

    @is_amazon_fulfilled.setter
    def is_amazon_fulfilled(self, is_amazon_fulfilled):
        """Sets the is_amazon_fulfilled of this FeesEstimateIdentifier.

        When true, the offer is fulfilled by Amazon.  # noqa: E501

        :param is_amazon_fulfilled: The is_amazon_fulfilled of this FeesEstimateIdentifier.  # noqa: E501
        :type: bool
        """

        self._is_amazon_fulfilled = is_amazon_fulfilled

    @property
    def price_to_estimate_fees(self):
        """Gets the price_to_estimate_fees of this FeesEstimateIdentifier.  # noqa: E501


        :return: The price_to_estimate_fees of this FeesEstimateIdentifier.  # noqa: E501
        :rtype: PriceToEstimateFees
        """
        return self._price_to_estimate_fees

    @price_to_estimate_fees.setter
    def price_to_estimate_fees(self, price_to_estimate_fees):
        """Sets the price_to_estimate_fees of this FeesEstimateIdentifier.


        :param price_to_estimate_fees: The price_to_estimate_fees of this FeesEstimateIdentifier.  # noqa: E501
        :type: PriceToEstimateFees
        """

        self._price_to_estimate_fees = price_to_estimate_fees

    @property
    def seller_input_identifier(self):
        """Gets the seller_input_identifier of this FeesEstimateIdentifier.  # noqa: E501

        A unique identifier provided by the caller to track this request.  # noqa: E501

        :return: The seller_input_identifier of this FeesEstimateIdentifier.  # noqa: E501
        :rtype: str
        """
        return self._seller_input_identifier

    @seller_input_identifier.setter
    def seller_input_identifier(self, seller_input_identifier):
        """Sets the seller_input_identifier of this FeesEstimateIdentifier.

        A unique identifier provided by the caller to track this request.  # noqa: E501

        :param seller_input_identifier: The seller_input_identifier of this FeesEstimateIdentifier.  # noqa: E501
        :type: str
        """

        self._seller_input_identifier = seller_input_identifier

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FeesEstimateIdentifier, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FeesEstimateIdentifier):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class CouponPaymentEvent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'posted_date': 'ModelDate',
        'coupon_id': 'str',
        'seller_coupon_description': 'str',
        'clip_or_redemption_count': 'int',
        'payment_event_id': 'str',
        'fee_component': 'FeeComponent',
        'charge_component': 'ChargeComponent',
        'total_amount': 'Currency'
    }

    attribute_map = {
        'posted_date': 'PostedDate',
        'coupon_id': 'CouponId',
        'seller_coupon_description': 'SellerCouponDescription',
        'clip_or_redemption_count': 'ClipOrRedemptionCount',
        'payment_event_id': 'PaymentEventId',
        'fee_component': 'FeeComponent',
        'charge_component': 'ChargeComponent',
        'total_amount': 'TotalAmount'
    }

    def __init__(self, posted_date=None, coupon_id=None, seller_coupon_description=None, clip_or_redemption_count=None, payment_event_id=None, fee_component=None, charge_component=None, total_amount=None):  # noqa: E501
        """CouponPaymentEvent - a model defined in Swagger"""  # noqa: E501
        self._posted_date = None
        self._coupon_id = None
        self._seller_coupon_description = None
        self._clip_or_redemption_count = None
        self._payment_event_id = None
        self._fee_component = None
        self._charge_component = None
        self._total_amount = None
        self.discriminator = None
        if posted_date is not None:
            self.posted_date = posted_date
        if coupon_id is not None:
            self.coupon_id = coupon_id
        if seller_coupon_description is not None:
            self.seller_coupon_description = seller_coupon_description
        if clip_or_redemption_count is not None:
            self.clip_or_redemption_count = clip_or_redemption_count
        if payment_event_id is not None:
            self.payment_event_id = payment_event_id
        if fee_component is not None:
            self.fee_component = fee_component
        if charge_component is not None:
            self.charge_component = charge_component
        if total_amount is not None:
            self.total_amount = total_amount

    @property
    def posted_date(self):
        """Gets the posted_date of this CouponPaymentEvent.  # noqa: E501


        :return: The posted_date of this CouponPaymentEvent.  # noqa: E501
        :rtype: ModelDate
        """
        return self._posted_date

    @posted_date.setter
    def posted_date(self, posted_date):
        """Sets the posted_date of this CouponPaymentEvent.


        :param posted_date: The posted_date of this CouponPaymentEvent.  # noqa: E501
        :type: ModelDate
        """

        self._posted_date = posted_date

    @property
    def coupon_id(self):
        """Gets the coupon_id of this CouponPaymentEvent.  # noqa: E501

        A coupon identifier.  # noqa: E501

        :return: The coupon_id of this CouponPaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._coupon_id

    @coupon_id.setter
    def coupon_id(self, coupon_id):
        """Sets the coupon_id of this CouponPaymentEvent.

        A coupon identifier.  # noqa: E501

        :param coupon_id: The coupon_id of this CouponPaymentEvent.  # noqa: E501
        :type: str
        """

        self._coupon_id = coupon_id

    @property
    def seller_coupon_description(self):
        """Gets the seller_coupon_description of this CouponPaymentEvent.  # noqa: E501

        The description provided by the seller when they created the coupon.  # noqa: E501

        :return: The seller_coupon_description of this CouponPaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._seller_coupon_description

    @seller_coupon_description.setter
    def seller_coupon_description(self, seller_coupon_description):
        """Sets the seller_coupon_description of this CouponPaymentEvent.

        The description provided by the seller when they created the coupon.  # noqa: E501

        :param seller_coupon_description: The seller_coupon_description of this CouponPaymentEvent.  # noqa: E501
        :type: str
        """

        self._seller_coupon_description = seller_coupon_description

    @property
    def clip_or_redemption_count(self):
        """Gets the clip_or_redemption_count of this CouponPaymentEvent.  # noqa: E501

        The number of coupon clips or redemptions.  # noqa: E501

        :return: The clip_or_redemption_count of this CouponPaymentEvent.  # noqa: E501
        :rtype: int
        """
        return self._clip_or_redemption_count

    @clip_or_redemption_count.setter
    def clip_or_redemption_count(self, clip_or_redemption_count):
        """Sets the clip_or_redemption_count of this CouponPaymentEvent.

        The number of coupon clips or redemptions.  # noqa: E501

        :param clip_or_redemption_count: The clip_or_redemption_count of this CouponPaymentEvent.  # noqa: E501
        :type: int
        """

        self._clip_or_redemption_count = clip_or_redemption_count

    @property
    def payment_event_id(self):
        """Gets the payment_event_id of this CouponPaymentEvent.  # noqa: E501

        A payment event identifier.  # noqa: E501

        :return: The payment_event_id of this CouponPaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._payment_event_id

    @payment_event_id.setter
    def payment_event_id(self, payment_event_id):
        """Sets the payment_event_id of this CouponPaymentEvent.

        A payment event identifier.  # noqa: E501

        :param payment_event_id: The payment_event_id of this CouponPaymentEvent.  # noqa: E501
        :type: str
        """

        self._payment_event_id = payment_event_id

    @property
    def fee_component(self):
        """Gets the fee_component of this CouponPaymentEvent.  # noqa: E501


        :return: The fee_component of this CouponPaymentEvent.  # noqa: E501
        :rtype: FeeComponent
        """
        return self._fee_component

    @fee_component.setter
    def fee_component(self, fee_component):
        """Sets the fee_component of this CouponPaymentEvent.


        :param fee_component: The fee_component of this CouponPaymentEvent.  # noqa: E501
        :type: FeeComponent
        """

        self._fee_component = fee_component

    @property
    def charge_component(self):
        """Gets the charge_component of this CouponPaymentEvent.  # noqa: E501


        :return: The charge_component of this CouponPaymentEvent.  # noqa: E501
        :rtype: ChargeComponent
        """
        return self._charge_component

    @charge_component.setter
    def charge_component(self, charge_component):
        """Sets the charge_component of this CouponPaymentEvent.


        :param charge_component: The charge_component of this CouponPaymentEvent.  # noqa: E501
        :type: ChargeComponent
        """

        self._charge_component = charge_component

    @property
    def total_amount(self):
        """Gets the total_amount of this CouponPaymentEvent.  # noqa: E501


        :return: The total_amount of this CouponPaymentEvent.  # noqa: E501
        :rtype: Currency
        """
        return self._total_amount

    @total_amount.setter
    def total_amount(self, total_amount):
        """Sets the total_amount of this CouponPaymentEvent.


        :param total_amount: The total_amount of this CouponPaymentEvent.  # noqa: E501
        :type: Currency
        """

        self._total_amount = total_amount

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CouponPaymentEvent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CouponPaymentEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Product Fees

    The Selling Partner API for Product Fees lets you programmatically retrieve estimated fees for a product. You can then account for those fees in your pricing.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class IncludedFeeDetail(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'fee_type': 'str',
        'fee_amount': 'MoneyType',
        'fee_promotion': 'MoneyType',
        'tax_amount': 'MoneyType',
        'final_fee': 'MoneyType'
    }

    attribute_map = {
        'fee_type': 'FeeType',
        'fee_amount': 'FeeAmount',
        'fee_promotion': 'FeePromotion',
        'tax_amount': 'TaxAmount',
        'final_fee': 'FinalFee'
    }

    def __init__(self, fee_type=None, fee_amount=None, fee_promotion=None, tax_amount=None, final_fee=None):  # noqa: E501
        """IncludedFeeDetail - a model defined in Swagger"""  # noqa: E501
        self._fee_type = None
        self._fee_amount = None
        self._fee_promotion = None
        self._tax_amount = None
        self._final_fee = None
        self.discriminator = None
        self.fee_type = fee_type
        self.fee_amount = fee_amount
        if fee_promotion is not None:
            self.fee_promotion = fee_promotion
        if tax_amount is not None:
            self.tax_amount = tax_amount
        self.final_fee = final_fee

    @property
    def fee_type(self):
        """Gets the fee_type of this IncludedFeeDetail.  # noqa: E501

        The type of fee charged to a seller.  # noqa: E501

        :return: The fee_type of this IncludedFeeDetail.  # noqa: E501
        :rtype: str
        """
        return self._fee_type

    @fee_type.setter
    def fee_type(self, fee_type):
        """Sets the fee_type of this IncludedFeeDetail.

        The type of fee charged to a seller.  # noqa: E501

        :param fee_type: The fee_type of this IncludedFeeDetail.  # noqa: E501
        :type: str
        """
        if fee_type is None:
            raise ValueError("Invalid value for `fee_type`, must not be `None`")  # noqa: E501

        self._fee_type = fee_type

    @property
    def fee_amount(self):
        """Gets the fee_amount of this IncludedFeeDetail.  # noqa: E501


        :return: The fee_amount of this IncludedFeeDetail.  # noqa: E501
        :rtype: MoneyType
        """
        return self._fee_amount

    @fee_amount.setter
    def fee_amount(self, fee_amount):
        """Sets the fee_amount of this IncludedFeeDetail.


        :param fee_amount: The fee_amount of this IncludedFeeDetail.  # noqa: E501
        :type: MoneyType
        """
        if fee_amount is None:
            raise ValueError("Invalid value for `fee_amount`, must not be `None`")  # noqa: E501

        self._fee_amount = fee_amount

    @property
    def fee_promotion(self):
        """Gets the fee_promotion of this IncludedFeeDetail.  # noqa: E501


        :return: The fee_promotion of this IncludedFeeDetail.  # noqa: E501
        :rtype: MoneyType
        """
        return self._fee_promotion

    @fee_promotion.setter
    def fee_promotion(self, fee_promotion):
        """Sets the fee_promotion of this IncludedFeeDetail.


        :param fee_promotion: The fee_promotion of this IncludedFeeDetail.  # noqa: E501
        :type: MoneyType
        """

        self._fee_promotion = fee_promotion

    @property
    def tax_amount(self):
        """Gets the tax_amount of this IncludedFeeDetail.  # noqa: E501


        :return: The tax_amount of this IncludedFeeDetail.  # noqa: E501
        :rtype: MoneyType
        """
        return self._tax_amount

    @tax_amount.setter
    def tax_amount(self, tax_amount):
        """Sets the tax_amount of this IncludedFeeDetail.


        :param tax_amount: The tax_amount of this IncludedFeeDetail.  # noqa: E501
        :type: MoneyType
        """

        self._tax_amount = tax_amount

    @property
    def final_fee(self):
        """Gets the final_fee of this IncludedFeeDetail.  # noqa: E501


        :return: The final_fee of this IncludedFeeDetail.  # noqa: E501
        :rtype: MoneyType
        """
        return self._final_fee

    @final_fee.setter
    def final_fee(self, final_fee):
        """Sets the final_fee of this IncludedFeeDetail.


        :param final_fee: The final_fee of this IncludedFeeDetail.  # noqa: E501
        :type: MoneyType
        """
        if final_fee is None:
            raise ValueError("Invalid value for `final_fee`, must not be `None`")  # noqa: E501

        self._final_fee = final_fee

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IncludedFeeDetail, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IncludedFeeDetail):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Sellers

    The Selling Partner API for Sellers lets you retrieve information on behalf of sellers about their seller account, such as the marketplaces they participate in. Along with listing the marketplaces that a seller can sell in, the API also provides additional information about the marketplace such as the default language and the default currency. The API also provides seller-specific information such as whether the seller has suspended listings in that marketplace.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Marketplace(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'country_code': 'str',
        'default_currency_code': 'str',
        'default_language_code': 'str',
        'domain_name': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'country_code': 'countryCode',
        'default_currency_code': 'defaultCurrencyCode',
        'default_language_code': 'defaultLanguageCode',
        'domain_name': 'domainName'
    }

    def __init__(self, id=None, name=None, country_code=None, default_currency_code=None, default_language_code=None, domain_name=None):  # noqa: E501
        """Marketplace - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._country_code = None
        self._default_currency_code = None
        self._default_language_code = None
        self._domain_name = None
        self.discriminator = None
        self.id = id
        self.name = name
        self.country_code = country_code
        self.default_currency_code = default_currency_code
        self.default_language_code = default_language_code
        self.domain_name = domain_name

    @property
    def id(self):
        """Gets the id of this Marketplace.  # noqa: E501

        The encrypted marketplace value.  # noqa: E501

        :return: The id of this Marketplace.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Marketplace.

        The encrypted marketplace value.  # noqa: E501

        :param id: The id of this Marketplace.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this Marketplace.  # noqa: E501

        Marketplace name.  # noqa: E501

        :return: The name of this Marketplace.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Marketplace.

        Marketplace name.  # noqa: E501

        :param name: The name of this Marketplace.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def country_code(self):
        """Gets the country_code of this Marketplace.  # noqa: E501

        The ISO 3166-1 alpha-2 format country code of the marketplace.  # noqa: E501

        :return: The country_code of this Marketplace.  # noqa: E501
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this Marketplace.

        The ISO 3166-1 alpha-2 format country code of the marketplace.  # noqa: E501

        :param country_code: The country_code of this Marketplace.  # noqa: E501
        :type: str
        """
        if country_code is None:
            raise ValueError("Invalid value for `country_code`, must not be `None`")  # noqa: E501

        self._country_code = country_code

    @property
    def default_currency_code(self):
        """Gets the default_currency_code of this Marketplace.  # noqa: E501

        The ISO 4217 format currency code of the marketplace.  # noqa: E501

        :return: The default_currency_code of this Marketplace.  # noqa: E501
        :rtype: str
        """
        return self._default_currency_code

    @default_currency_code.setter
    def default_currency_code(self, default_currency_code):
        """Sets the default_currency_code of this Marketplace.

        The ISO 4217 format currency code of the marketplace.  # noqa: E501

        :param default_currency_code: The default_currency_code of this Marketplace.  # noqa: E501
        :type: str
        """
        if default_currency_code is None:
            raise ValueError("Invalid value for `default_currency_code`, must not be `None`")  # noqa: E501

        self._default_currency_code = default_currency_code

    @property
    def default_language_code(self):
        """Gets the default_language_code of this Marketplace.  # noqa: E501

        The ISO 639-1 format language code of the marketplace.  # noqa: E501

        :return: The default_language_code of this Marketplace.  # noqa: E501
        :rtype: str
        """
        return self._default_language_code

    @default_language_code.setter
    def default_language_code(self, default_language_code):
        """Sets the default_language_code of this Marketplace.

        The ISO 639-1 format language code of the marketplace.  # noqa: E501

        :param default_language_code: The default_language_code of this Marketplace.  # noqa: E501
        :type: str
        """
        if default_language_code is None:
            raise ValueError("Invalid value for `default_language_code`, must not be `None`")  # noqa: E501

        self._default_language_code = default_language_code

    @property
    def domain_name(self):
        """Gets the domain_name of this Marketplace.  # noqa: E501

        The domain name of the marketplace.  # noqa: E501

        :return: The domain_name of this Marketplace.  # noqa: E501
        :rtype: str
        """
        return self._domain_name

    @domain_name.setter
    def domain_name(self, domain_name):
        """Sets the domain_name of this Marketplace.

        The domain name of the marketplace.  # noqa: E501

        :param domain_name: The domain_name of this Marketplace.  # noqa: E501
        :type: str
        """
        if domain_name is None:
            raise ValueError("Invalid value for `domain_name`, must not be `None`")  # noqa: E501

        self._domain_name = domain_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Marketplace, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Marketplace):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class PayWithAmazonEvent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'seller_order_id': 'str',
        'transaction_posted_date': 'ModelDate',
        'business_object_type': 'str',
        'sales_channel': 'str',
        'charge': 'ChargeComponent',
        'fee_list': 'FeeComponentList',
        'payment_amount_type': 'str',
        'amount_description': 'str',
        'fulfillment_channel': 'str',
        'store_name': 'str'
    }

    attribute_map = {
        'seller_order_id': 'SellerOrderId',
        'transaction_posted_date': 'TransactionPostedDate',
        'business_object_type': 'BusinessObjectType',
        'sales_channel': 'SalesChannel',
        'charge': 'Charge',
        'fee_list': 'FeeList',
        'payment_amount_type': 'PaymentAmountType',
        'amount_description': 'AmountDescription',
        'fulfillment_channel': 'FulfillmentChannel',
        'store_name': 'StoreName'
    }

    def __init__(self, seller_order_id=None, transaction_posted_date=None, business_object_type=None, sales_channel=None, charge=None, fee_list=None, payment_amount_type=None, amount_description=None, fulfillment_channel=None, store_name=None):  # noqa: E501
        """PayWithAmazonEvent - a model defined in Swagger"""  # noqa: E501
        self._seller_order_id = None
        self._transaction_posted_date = None
        self._business_object_type = None
        self._sales_channel = None
        self._charge = None
        self._fee_list = None
        self._payment_amount_type = None
        self._amount_description = None
        self._fulfillment_channel = None
        self._store_name = None
        self.discriminator = None
        if seller_order_id is not None:
            self.seller_order_id = seller_order_id
        if transaction_posted_date is not None:
            self.transaction_posted_date = transaction_posted_date
        if business_object_type is not None:
            self.business_object_type = business_object_type
        if sales_channel is not None:
            self.sales_channel = sales_channel
        if charge is not None:
            self.charge = charge
        if fee_list is not None:
            self.fee_list = fee_list
        if payment_amount_type is not None:
            self.payment_amount_type = payment_amount_type
        if amount_description is not None:
            self.amount_description = amount_description
        if fulfillment_channel is not None:
            self.fulfillment_channel = fulfillment_channel
        if store_name is not None:
            self.store_name = store_name

    @property
    def seller_order_id(self):
        """Gets the seller_order_id of this PayWithAmazonEvent.  # noqa: E501

        An order identifier that is specified by the seller.  # noqa: E501

        :return: The seller_order_id of this PayWithAmazonEvent.  # noqa: E501
        :rtype: str
        """
        return self._seller_order_id

    @seller_order_id.setter
    def seller_order_id(self, seller_order_id):
        """Sets the seller_order_id of this PayWithAmazonEvent.

        An order identifier that is specified by the seller.  # noqa: E501

        :param seller_order_id: The seller_order_id of this PayWithAmazonEvent.  # noqa: E501
        :type: str
        """

        self._seller_order_id = seller_order_id

    @property
    def transaction_posted_date(self):
        """Gets the transaction_posted_date of this PayWithAmazonEvent.  # noqa: E501


        :return: The transaction_posted_date of this PayWithAmazonEvent.  # noqa: E501
        :rtype: ModelDate
        """
        return self._transaction_posted_date

    @transaction_posted_date.setter
    def transaction_posted_date(self, transaction_posted_date):
        """Sets the transaction_posted_date of this PayWithAmazonEvent.


        :param transaction_posted_date: The transaction_posted_date of this PayWithAmazonEvent.  # noqa: E501
        :type: ModelDate
        """

        self._transaction_posted_date = transaction_posted_date

    @property
    def business_object_type(self):
        """Gets the business_object_type of this PayWithAmazonEvent.  # noqa: E501

        The type of business object.  # noqa: E501

        :return: The business_object_type of this PayWithAmazonEvent.  # noqa: E501
        :rtype: str
        """
        return self._business_object_type

    @business_object_type.setter
    def business_object_type(self, business_object_type):
        """Sets the business_object_type of this PayWithAmazonEvent.

        The type of business object.  # noqa: E501

        :param business_object_type: The business_object_type of this PayWithAmazonEvent.  # noqa: E501
        :type: str
        """

        self._business_object_type = business_object_type

    @property
    def sales_channel(self):
        """Gets the sales_channel of this PayWithAmazonEvent.  # noqa: E501

        The sales channel for the transaction.  # noqa: E501

        :return: The sales_channel of this PayWithAmazonEvent.  # noqa: E501
        :rtype: str
        """
        return self._sales_channel

    @sales_channel.setter
    def sales_channel(self, sales_channel):
        """Sets the sales_channel of this PayWithAmazonEvent.

        The sales channel for the transaction.  # noqa: E501

        :param sales_channel: The sales_channel of this PayWithAmazonEvent.  # noqa: E501
        :type: str
        """

        self._sales_channel = sales_channel

    @property
    def charge(self):
        """Gets the charge of this PayWithAmazonEvent.  # noqa: E501


        :return: The charge of this PayWithAmazonEvent.  # noqa: E501
        :rtype: ChargeComponent
        """
        return self._charge

    @charge.setter
    def charge(self, charge):
        """Sets the charge of this PayWithAmazonEvent.


        :param charge: The charge of this PayWithAmazonEvent.  # noqa: E501
        :type: ChargeComponent
        """

        self._charge = charge

    @property
    def fee_list(self):
        """Gets the fee_list of this PayWithAmazonEvent.  # noqa: E501


        :return: The fee_list of this PayWithAmazonEvent.  # noqa: E501
        :rtype: FeeComponentList
        """
        return self._fee_list

    @fee_list.setter
    def fee_list(self, fee_list):
        """Sets the fee_list of this PayWithAmazonEvent.


        :param fee_list: The fee_list of this PayWithAmazonEvent.  # noqa: E501
        :type: FeeComponentList
        """

        self._fee_list = fee_list

    @property
    def payment_amount_type(self):
        """Gets the payment_amount_type of this PayWithAmazonEvent.  # noqa: E501

        The type of payment.  Possible values:  * Sales  # noqa: E501

        :return: The payment_amount_type of this PayWithAmazonEvent.  # noqa: E501
        :rtype: str
        """
        return self._payment_amount_type

    @payment_amount_type.setter
    def payment_amount_type(self, payment_amount_type):
        """Sets the payment_amount_type of this PayWithAmazonEvent.

        The type of payment.  Possible values:  * Sales  # noqa: E501

        :param payment_amount_type: The payment_amount_type of this PayWithAmazonEvent.  # noqa: E501
        :type: str
        """

        self._payment_amount_type = payment_amount_type

    @property
    def amount_description(self):
        """Gets the amount_description of this PayWithAmazonEvent.  # noqa: E501

        A short description of this payment event.  # noqa: E501

        :return: The amount_description of this PayWithAmazonEvent.  # noqa: E501
        :rtype: str
        """
        return self._amount_description

    @amount_description.setter
    def amount_description(self, amount_description):
        """Sets the amount_description of this PayWithAmazonEvent.

        A short description of this payment event.  # noqa: E501

        :param amount_description: The amount_description of this PayWithAmazonEvent.  # noqa: E501
        :type: str
        """

        self._amount_description = amount_description

    @property
    def fulfillment_channel(self):
        """Gets the fulfillment_channel of this PayWithAmazonEvent.  # noqa: E501

        The fulfillment channel.  Possible values:  * AFN - Amazon Fulfillment Network (Fulfillment by Amazon)  * MFN - Merchant Fulfillment Network (self-fulfilled)  # noqa: E501

        :return: The fulfillment_channel of this PayWithAmazonEvent.  # noqa: E501
        :rtype: str
        """
        return self._fulfillment_channel

    @fulfillment_channel.setter
    def fulfillment_channel(self, fulfillment_channel):
        """Sets the fulfillment_channel of this PayWithAmazonEvent.

        The fulfillment channel.  Possible values:  * AFN - Amazon Fulfillment Network (Fulfillment by Amazon)  * MFN - Merchant Fulfillment Network (self-fulfilled)  # noqa: E501

        :param fulfillment_channel: The fulfillment_channel of this PayWithAmazonEvent.  # noqa: E501
        :type: str
        """

        self._fulfillment_channel = fulfillment_channel

    @property
    def store_name(self):
        """Gets the store_name of this PayWithAmazonEvent.  # noqa: E501

        The store name where the event occurred.  # noqa: E501

        :return: The store_name of this PayWithAmazonEvent.  # noqa: E501
        :rtype: str
        """
        return self._store_name

    @store_name.setter
    def store_name(self, store_name):
        """Sets the store_name of this PayWithAmazonEvent.

        The store name where the event occurred.  # noqa: E501

        :param store_name: The store_name of this PayWithAmazonEvent.  # noqa: E501
        :type: str
        """

        self._store_name = store_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PayWithAmazonEvent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PayWithAmazonEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class TDSReimbursementEvent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'posted_date': 'ModelDate',
        'tds_order_id': 'str',
        'reimbursed_amount': 'Currency'
    }

    attribute_map = {
        'posted_date': 'PostedDate',
        'tds_order_id': 'TdsOrderId',
        'reimbursed_amount': 'ReimbursedAmount'
    }

    def __init__(self, posted_date=None, tds_order_id=None, reimbursed_amount=None):  # noqa: E501
        """TDSReimbursementEvent - a model defined in Swagger"""  # noqa: E501
        self._posted_date = None
        self._tds_order_id = None
        self._reimbursed_amount = None
        self.discriminator = None
        if posted_date is not None:
            self.posted_date = posted_date
        if tds_order_id is not None:
            self.tds_order_id = tds_order_id
        if reimbursed_amount is not None:
            self.reimbursed_amount = reimbursed_amount

    @property
    def posted_date(self):
        """Gets the posted_date of this TDSReimbursementEvent.  # noqa: E501


        :return: The posted_date of this TDSReimbursementEvent.  # noqa: E501
        :rtype: ModelDate
        """
        return self._posted_date

    @posted_date.setter
    def posted_date(self, posted_date):
        """Sets the posted_date of this TDSReimbursementEvent.


        :param posted_date: The posted_date of this TDSReimbursementEvent.  # noqa: E501
        :type: ModelDate
        """

        self._posted_date = posted_date

    @property
    def tds_order_id(self):
        """Gets the tds_order_id of this TDSReimbursementEvent.  # noqa: E501

        A tax deduction at source (TDS) claim identifier.  # noqa: E501

        :return: The tds_order_id of this TDSReimbursementEvent.  # noqa: E501
        :rtype: str
        """
        return self._tds_order_id

    @tds_order_id.setter
    def tds_order_id(self, tds_order_id):
        """Sets the tds_order_id of this TDSReimbursementEvent.

        A tax deduction at source (TDS) claim identifier.  # noqa: E501

        :param tds_order_id: The tds_order_id of this TDSReimbursementEvent.  # noqa: E501
        :type: str
        """

        self._tds_order_id = tds_order_id

    @property
    def reimbursed_amount(self):
        """Gets the reimbursed_amount of this TDSReimbursementEvent.  # noqa: E501


        :return: The reimbursed_amount of this TDSReimbursementEvent.  # noqa: E501
        :rtype: Currency
        """
        return self._reimbursed_amount

    @reimbursed_amount.setter
    def reimbursed_amount(self, reimbursed_amount):
        """Sets the reimbursed_amount of this TDSReimbursementEvent.


        :param reimbursed_amount: The reimbursed_amount of this TDSReimbursementEvent.  # noqa: E501
        :type: Currency
        """

        self._reimbursed_amount = reimbursed_amount

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TDSReimbursementEvent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TDSReimbursementEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Orders

    The Selling Partner API for Orders helps you programmatically retrieve order information. These APIs let you develop fast, flexible, custom applications in areas like order synchronization, order research, and demand-based decision support tools.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class OrderItemsList(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'order_items': 'OrderItemList',
        'next_token': 'str',
        'amazon_order_id': 'str'
    }

    attribute_map = {
        'order_items': 'OrderItems',
        'next_token': 'NextToken',
        'amazon_order_id': 'AmazonOrderId'
    }

    def __init__(self, order_items=None, next_token=None, amazon_order_id=None):  # noqa: E501
        """OrderItemsList - a model defined in Swagger"""  # noqa: E501
        self._order_items = None
        self._next_token = None
        self._amazon_order_id = None
        self.discriminator = None
        self.order_items = order_items
        if next_token is not None:
            self.next_token = next_token
        self.amazon_order_id = amazon_order_id

    @property
    def order_items(self):
        """Gets the order_items of this OrderItemsList.  # noqa: E501


        :return: The order_items of this OrderItemsList.  # noqa: E501
        :rtype: OrderItemList
        """
        return self._order_items

    @order_items.setter
    def order_items(self, order_items):
        """Sets the order_items of this OrderItemsList.


        :param order_items: The order_items of this OrderItemsList.  # noqa: E501
        :type: OrderItemList
        """
        if order_items is None:
            raise ValueError("Invalid value for `order_items`, must not be `None`")  # noqa: E501

        self._order_items = order_items

    @property
    def next_token(self):
        """Gets the next_token of this OrderItemsList.  # noqa: E501

        When present and not empty, pass this string token in the next request to return the next response page.  # noqa: E501

        :return: The next_token of this OrderItemsList.  # noqa: E501
        :rtype: str
        """
        return self._next_token

    @next_token.setter
    def next_token(self, next_token):
        """Sets the next_token of this OrderItemsList.

        When present and not empty, pass this string token in the next request to return the next response page.  # noqa: E501

        :param next_token: The next_token of this OrderItemsList.  # noqa: E501
        :type: str
        """

        self._next_token = next_token

    @property
    def amazon_order_id(self):
        """Gets the amazon_order_id of this OrderItemsList.  # noqa: E501

        An Amazon-defined order identifier, in 3-7-7 format.  # noqa: E501

        :return: The amazon_order_id of this OrderItemsList.  # noqa: E501
        :rtype: str
        """
        return self._amazon_order_id

    @amazon_order_id.setter
    def amazon_order_id(self, amazon_order_id):
        """Sets the amazon_order_id of this OrderItemsList.

        An Amazon-defined order identifier, in 3-7-7 format.  # noqa: E501

        :param amazon_order_id: The amazon_order_id of this OrderItemsList.  # noqa: E501
        :type: str
        """
        if amazon_order_id is None:
            raise ValueError("Invalid value for `amazon_order_id`, must not be `None`")  # noqa: E501

        self._amazon_order_id = amazon_order_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OrderItemsList, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrderItemsList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Sellers

    The Selling Partner API for Sellers lets you retrieve information on behalf of sellers about their seller account, such as the marketplaces they participate in. Along with listing the marketplaces that a seller can sell in, the API also provides additional information about the marketplace such as the default language and the default currency. The API also provides seller-specific information such as whether the seller has suspended listings in that marketplace.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Error(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'code': 'str',
        'message': 'str',
        'details': 'str'
    }

    attribute_map = {
        'code': 'code',
        'message': 'message',
        'details': 'details'
    }

    def __init__(self, code=None, message=None, details=None):  # noqa: E501
        """Error - a model defined in Swagger"""  # noqa: E501
        self._code = None
        self._message = None
        self._details = None
        self.discriminator = None
        self.code = code
        self.message = message
        if details is not None:
            self.details = details

    @property
    def code(self):
        """Gets the code of this Error.  # noqa: E501

        An error code that identifies the type of error that occured.  # noqa: E501

        :return: The code of this Error.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this Error.

        An error code that identifies the type of error that occured.  # noqa: E501

        :param code: The code of this Error.  # noqa: E501
        :type: str
        """
        if code is None:
            raise ValueError("Invalid value for `code`, must not be `None`")  # noqa: E501

        self._code = code

    @property
    def message(self):
        """Gets the message of this Error.  # noqa: E501

        A message that describes the error condition in a human-readable form.  # noqa: E501

        :return: The message of this Error.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this Error.

        A message that describes the error condition in a human-readable form.  # noqa: E501

        :param message: The message of this Error.  # noqa: E501
        :type: str
        """
        if message is None:
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    @property
    def details(self):
        """Gets the details of this Error.  # noqa: E501

        Additional details that can help the caller understand or fix the issue.  # noqa: E501

        :return: The details of this Error.  # noqa: E501
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this Error.

        Additional details that can help the caller understand or fix the issue.  # noqa: E501

        :param details: The details of this Error.  # noqa: E501
        :type: str
        """

        self._details = details

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Error, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Error):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



def test_access_token_client_success():
    from auth.access_token_client import AccessTokenClient
    from auth.credentials import Credentials
    res = AccessTokenClient().get_auth()
    print(res)
    assert hasattr(res, 'access_token')
    res = AccessTokenClient().get_auth()
    print(res)
    assert hasattr(res, 'access_token')





from __future__ import print_function
import os
import datetime
import hashlib
import hmac
import logging
import urllib.parse
from collections import OrderedDict
from requests.auth import AuthBase
from requests.compat import urlencode, quote, urlparse

USE_BOTO3 = False
try:
    import boto3

    USE_BOTO3 = False
except ImportError:
    pass

__version__ = '0.4'

log = logging.getLogger(__name__)


def sign_msg(key, msg):
    ''' Sign message using key '''
    return hmac.new(key, msg.encode('utf-8'), hashlib.sha256).digest()


class AWSSigV4(AuthBase):

    def __init__(self, service, **kwargs):
        ''' Create authentication mechanism

        :param service: AWS Service identifier, for example `ec2`.  This is required.
        :param region:  AWS Region, for example `us-east-1`.  If not provided, it will be set using
            the environment variables `AWS_DEFAULT_REGION` or using boto3, if available.
        :param session: If boto3 is available, will attempt to get credentials using boto3,
            unless passed explicitly.  If using boto3, the provided session will be used or a new
            session will be created.

        '''
        # Set Service
        self.service = service

        # First, get credentials passed explicitly
        self.aws_access_key_id = kwargs.get('aws_access_key_id')
        self.aws_secret_access_key = kwargs.get('aws_secret_access_key')
        self.aws_session_token = kwargs.get('aws_session_token')
        # Next, try environment variables or use boto3

        # Last, fail if still not found
        if self.aws_access_key_id is None or self.aws_secret_access_key is None:
            raise KeyError("AWS Access Key ID and Secret Access Key are required")

        # Get Region passed explicitly
        self.region = kwargs.get('region')
        # Next, try environment variables or use boto3
        if self.region is None:
            self.region = os.environ.get('SP_AWS_REGION', 'us-east-1')

    def __call__(self, r):
        ''' Called to add authentication information to request

        :param r: `requests.models.PreparedRequest` object to modify

        :returns: `requests.models.PreparedRequest`, modified to add authentication

        '''
        # Create a date for headers and the credential string
        t = datetime.datetime.utcnow()
        self.amzdate = t.strftime('%Y%m%dT%H%M%SZ')
        self.datestamp = t.strftime('%Y%m%d')
        log.debug("Starting authentication with amzdate=%s", self.amzdate)

        # Parse request to get URL parts
        p = urlparse(r.url)

        host = p.hostname
        uri = urllib.parse.quote(p.path)

        if len(p.query) > 0:
            qs = dict(map(lambda i: i.split('='), p.query.split('&')))
        else:
            qs = dict()

        canonical_querystring = "&".join(map(lambda x: '='.join(x), sorted(qs.items())))
        headers_to_sign = {'host': host, 'x-amz-date': self.amzdate}
        if self.aws_session_token is not None:
            headers_to_sign['x-amz-security-token'] = self.aws_session_token

        ordered_headers = OrderedDict(sorted(headers_to_sign.items(), key=lambda t: t[0]))
        canonical_headers = ''.join(map(lambda h: ":".join(h) + '\n', ordered_headers.items()))
        signed_headers = ';'.join(ordered_headers.keys())

        if r.method == 'GET':
            payload_hash = hashlib.sha256(''.encode('utf-8')).hexdigest()
        else:
            if r.body:
                payload_hash = hashlib.sha256(r.body.encode('utf-8')).hexdigest()
            else:
                payload_hash = hashlib.sha256(''.encode('utf-8')).hexdigest()

        canonical_request = '\n'.join([r.method, uri, canonical_querystring,
                                       canonical_headers, signed_headers, payload_hash])

        credential_scope = '/'.join([self.datestamp, self.region, self.service, 'aws4_request'])
        string_to_sign = '\n'.join(['AWS4-HMAC-SHA256', self.amzdate,
                                    credential_scope, hashlib.sha256(canonical_request.encode('utf-8')).hexdigest()])
        log.debug("String-to-Sign: '%s'", string_to_sign)

        kDate = sign_msg(('AWS4' + self.aws_secret_access_key).encode('utf-8'), self.datestamp)
        kRegion = sign_msg(kDate, self.region)
        kService = sign_msg(kRegion, self.service)
        kSigning = sign_msg(kService, 'aws4_request')
        signature = hmac.new(kSigning, string_to_sign.encode('utf-8'), hashlib.sha256).hexdigest()

        authorization_header = "AWS4-HMAC-SHA256 Credential={}/{}, SignedHeaders={}, Signature={}".format(
            self.aws_access_key_id, credential_scope, signed_headers, signature)
        r.headers.update({
            'host': host,
            'x-amz-date': self.amzdate,
            'Authorization': authorization_header,
            'x-amz-security-token': self.aws_session_token
        })
        return r




import requests

from sp_api.api.notifications.models.delete_subscription_by_id_response import DeleteSubscriptionByIdResponse
from sp_api.api.notifications.models.get_subscription_by_id_response import GetSubscriptionByIdResponse
from sp_api.api.reports.models.create_report_response import CreateReportResponse
from sp_api.api.reports.models.create_report_schedule_response import CreateReportScheduleResponse
from sp_api.api.reports.models.create_report_schedule_specification import CreateReportScheduleSpecification
from sp_api.api.reports.models.get_report_document_response import GetReportDocumentResponse
from sp_api.api.reports.models.get_report_response import GetReportResponse
from sp_api.base import sp_endpoint, fill_query_params, SellingApiException
from sp_api.base import Client, Marketplaces
import base64
from Crypto.Cipher import AES


def decrypt_aes(content, key, iv):
    key = base64.b64decode(key)
    iv = base64.b64decode(iv)
    decrypter = AES.new(key, AES.MODE_CBC, iv)
    return decrypter.decrypt(content).decode('iso-8859-1')


class Reports(Client):
    def __init__(self, marketplace=Marketplaces.US, refresh_token=None):
        super().__init__(marketplace, refresh_token)

    @sp_endpoint('/reports/2020-09-04/reports', method='POST')
    def create_report(self, **kwargs):
        """
        Creates a report.

        **Usage Plan:**

        | Rate (requests per second) | Burst |
        | ---- | ---- |
        | 0.0167 | 15 |

        For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
        :param kwargs:
        :return:
        """
        return CreateReportResponse(
            **self._request(kwargs.pop('path'), data={**kwargs}).json()
        )

    @sp_endpoint('/reports/2020-09-04/reports/{}')
    def get_report(self, report_id, **kwargs):
        """
        Returns report details (including the reportDocumentId, if available) for the report that you specify.

        **Usage Plan:**

        | Rate (requests per second) | Burst |
        | ---- | ---- |
        | 2.0 | 15 |

        For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
        :param report_id:
        :return:
        """
        return GetReportResponse(
            **self._request(fill_query_params(kwargs.pop('path'), report_id)).json()
        )

    @sp_endpoint('/reports/2020-09-04/documents/{}')
    def get_report_document(self, document_id, decrypt: bool = False, **kwargs):
        """
        Returns the information required for retrieving a report document's contents. This includes a presigned URL for the report document as well as the information required to decrypt the document's contents.

        **Usage Plan:**

        | Rate (requests per second) | Burst |
        | ---- | ---- |
        | 0.0167 | 15 |

        For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
        :param decrypt:
        :param document_id:
        :param kwargs:
        :return:
        """
        res = self._request(fill_query_params(kwargs.pop('path'), document_id)).json()
        if decrypt:
            res.get('payload').update({
                'document': self.decrypt_report_document(
                    res.get('payload').get('url'),
                    res.get('payload').get('encryptionDetails').get('initializationVector'),
                    res.get('payload').get('encryptionDetails').get('key'),
                    res.get('payload').get('encryptionDetails').get('standard')
                )
            })
        return GetReportDocumentResponse(
            **res
        )

    @sp_endpoint('/reports/2020-09-04/schedules', method='POST')
    def create_report_schedule(self, **kwargs):
        """
        Creates a report schedule. If a report schedule with the same report type and marketplace IDs already exists, it will be cancelled and replaced with this one.

        **Usage Plan:**

        | Rate (requests per second) | Burst |
        | ---- | ---- |
        | 0.0222 | 10 |

        For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
        :param kwargs:
        :return:
        """
        return CreateReportScheduleResponse(**self._request(kwargs.pop('path'), data=kwargs).json())

    @sp_endpoint('/reports/2020-09-04/schedules/{}', method='DELETE')
    def delete_report_schedule(self, schedule_id, **kwargs):
        """
        Cancels the report schedule that you specify.

        **Usage Plan:**

        | Rate (requests per second) | Burst |
        | ---- | ---- |
        | 0.0222 | 10 |

        For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
        :param schedule_id:
        :param kwargs:
        :return:
        """
        return DeleteSubscriptionByIdResponse(
            **self._request(fill_query_params(kwargs.pop('path'), schedule_id), params=kwargs).json()
        )

    @sp_endpoint('/reports/2020-09-04/schedules/{}')
    def get_report_schedule(self, schedule_id, **kwargs):
        """
        Cancels the report schedule that you specify.

        **Usage Plan:**

        | Rate (requests per second) | Burst |
        | ---- | ---- |
        | 0.0222 | 10 |

        For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
        :param schedule_id:
        :param kwargs:
        :return:
        """
        return GetSubscriptionByIdResponse(
            **self._request(fill_query_params(kwargs.pop('path'), schedule_id), params=kwargs).json()
        )

    @staticmethod
    def decrypt_report_document(url, initialization_vector, key, encryption_standard):
        """
        Decrypts a report document, currently AES encryption is implemented
        :param url:
        :param initialization_vector:
        :param key:
        :param encryption_standard:
        :return:
        """
        if encryption_standard == 'AES':
            return decrypt_aes(requests.get(url).content, key, initialization_vector)
        raise SellingApiException([{
            'message': 'Only AES decryption is implemented. Contribute: https://github.com/saleweaver/python-sp-api'
        }])



# coding: utf-8

"""
    Selling Partner API for Pricing

    The Selling Partner API for Pricing helps you programmatically retrieve product pricing and offer information for Amazon Marketplace products.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Summary(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'total_offer_count': 'int',
        'number_of_offers': 'NumberOfOffers',
        'lowest_prices': 'LowestPrices',
        'buy_box_prices': 'BuyBoxPrices',
        'list_price': 'MoneyType',
        'suggested_lower_price_plus_shipping': 'MoneyType',
        'buy_box_eligible_offers': 'BuyBoxEligibleOffers',
        'offers_available_time': 'datetime'
    }

    attribute_map = {
        'total_offer_count': 'TotalOfferCount',
        'number_of_offers': 'NumberOfOffers',
        'lowest_prices': 'LowestPrices',
        'buy_box_prices': 'BuyBoxPrices',
        'list_price': 'ListPrice',
        'suggested_lower_price_plus_shipping': 'SuggestedLowerPricePlusShipping',
        'buy_box_eligible_offers': 'BuyBoxEligibleOffers',
        'offers_available_time': 'OffersAvailableTime'
    }

    def __init__(self, total_offer_count=None, number_of_offers=None, lowest_prices=None, buy_box_prices=None, list_price=None, suggested_lower_price_plus_shipping=None, buy_box_eligible_offers=None, offers_available_time=None):  # noqa: E501
        """Summary - a model defined in Swagger"""  # noqa: E501
        self._total_offer_count = None
        self._number_of_offers = None
        self._lowest_prices = None
        self._buy_box_prices = None
        self._list_price = None
        self._suggested_lower_price_plus_shipping = None
        self._buy_box_eligible_offers = None
        self._offers_available_time = None
        self.discriminator = None
        self.total_offer_count = total_offer_count
        if number_of_offers is not None:
            self.number_of_offers = number_of_offers
        if lowest_prices is not None:
            self.lowest_prices = lowest_prices
        if buy_box_prices is not None:
            self.buy_box_prices = buy_box_prices
        if list_price is not None:
            self.list_price = list_price
        if suggested_lower_price_plus_shipping is not None:
            self.suggested_lower_price_plus_shipping = suggested_lower_price_plus_shipping
        if buy_box_eligible_offers is not None:
            self.buy_box_eligible_offers = buy_box_eligible_offers
        if offers_available_time is not None:
            self.offers_available_time = offers_available_time

    @property
    def total_offer_count(self):
        """Gets the total_offer_count of this Summary.  # noqa: E501

        The number of unique offers contained in NumberOfOffers.  # noqa: E501

        :return: The total_offer_count of this Summary.  # noqa: E501
        :rtype: int
        """
        return self._total_offer_count

    @total_offer_count.setter
    def total_offer_count(self, total_offer_count):
        """Sets the total_offer_count of this Summary.

        The number of unique offers contained in NumberOfOffers.  # noqa: E501

        :param total_offer_count: The total_offer_count of this Summary.  # noqa: E501
        :type: int
        """
        if total_offer_count is None:
            raise ValueError("Invalid value for `total_offer_count`, must not be `None`")  # noqa: E501

        self._total_offer_count = total_offer_count

    @property
    def number_of_offers(self):
        """Gets the number_of_offers of this Summary.  # noqa: E501


        :return: The number_of_offers of this Summary.  # noqa: E501
        :rtype: NumberOfOffers
        """
        return self._number_of_offers

    @number_of_offers.setter
    def number_of_offers(self, number_of_offers):
        """Sets the number_of_offers of this Summary.


        :param number_of_offers: The number_of_offers of this Summary.  # noqa: E501
        :type: NumberOfOffers
        """

        self._number_of_offers = number_of_offers

    @property
    def lowest_prices(self):
        """Gets the lowest_prices of this Summary.  # noqa: E501


        :return: The lowest_prices of this Summary.  # noqa: E501
        :rtype: LowestPrices
        """
        return self._lowest_prices

    @lowest_prices.setter
    def lowest_prices(self, lowest_prices):
        """Sets the lowest_prices of this Summary.


        :param lowest_prices: The lowest_prices of this Summary.  # noqa: E501
        :type: LowestPrices
        """

        self._lowest_prices = lowest_prices

    @property
    def buy_box_prices(self):
        """Gets the buy_box_prices of this Summary.  # noqa: E501


        :return: The buy_box_prices of this Summary.  # noqa: E501
        :rtype: BuyBoxPrices
        """
        return self._buy_box_prices

    @buy_box_prices.setter
    def buy_box_prices(self, buy_box_prices):
        """Sets the buy_box_prices of this Summary.


        :param buy_box_prices: The buy_box_prices of this Summary.  # noqa: E501
        :type: BuyBoxPrices
        """

        self._buy_box_prices = buy_box_prices

    @property
    def list_price(self):
        """Gets the list_price of this Summary.  # noqa: E501


        :return: The list_price of this Summary.  # noqa: E501
        :rtype: MoneyType
        """
        return self._list_price

    @list_price.setter
    def list_price(self, list_price):
        """Sets the list_price of this Summary.


        :param list_price: The list_price of this Summary.  # noqa: E501
        :type: MoneyType
        """

        self._list_price = list_price

    @property
    def suggested_lower_price_plus_shipping(self):
        """Gets the suggested_lower_price_plus_shipping of this Summary.  # noqa: E501


        :return: The suggested_lower_price_plus_shipping of this Summary.  # noqa: E501
        :rtype: MoneyType
        """
        return self._suggested_lower_price_plus_shipping

    @suggested_lower_price_plus_shipping.setter
    def suggested_lower_price_plus_shipping(self, suggested_lower_price_plus_shipping):
        """Sets the suggested_lower_price_plus_shipping of this Summary.


        :param suggested_lower_price_plus_shipping: The suggested_lower_price_plus_shipping of this Summary.  # noqa: E501
        :type: MoneyType
        """

        self._suggested_lower_price_plus_shipping = suggested_lower_price_plus_shipping

    @property
    def buy_box_eligible_offers(self):
        """Gets the buy_box_eligible_offers of this Summary.  # noqa: E501


        :return: The buy_box_eligible_offers of this Summary.  # noqa: E501
        :rtype: BuyBoxEligibleOffers
        """
        return self._buy_box_eligible_offers

    @buy_box_eligible_offers.setter
    def buy_box_eligible_offers(self, buy_box_eligible_offers):
        """Sets the buy_box_eligible_offers of this Summary.


        :param buy_box_eligible_offers: The buy_box_eligible_offers of this Summary.  # noqa: E501
        :type: BuyBoxEligibleOffers
        """

        self._buy_box_eligible_offers = buy_box_eligible_offers

    @property
    def offers_available_time(self):
        """Gets the offers_available_time of this Summary.  # noqa: E501

        When the status is ActiveButTooSoonForProcessing, this is the time when the offers will be available for processing.  # noqa: E501

        :return: The offers_available_time of this Summary.  # noqa: E501
        :rtype: datetime
        """
        return self._offers_available_time

    @offers_available_time.setter
    def offers_available_time(self, offers_available_time):
        """Sets the offers_available_time of this Summary.

        When the status is ActiveButTooSoonForProcessing, this is the time when the offers will be available for processing.  # noqa: E501

        :param offers_available_time: The offers_available_time of this Summary.  # noqa: E501
        :type: datetime
        """

        self._offers_available_time = offers_available_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Summary, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Summary):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from datetime import datetime, timedelta

from sp_api.api import Reports, Orders
from sp_api.api.reports.models.create_report_specification import CreateReportSpecification
from sp_api.base import Marketplaces, Schedules


def test_create_report():
    print(Reports().create_report(reportType='GET_FBA_ESTIMATED_FBA_FEES_TXT_DATA'))


def test_get_report():
    print(Reports().get_report('597asdf8618'))


def test_get_report_document_w_decrypt():
    res = Reports().get_report_document('as',
                                        decrypt=True)
    print(res)
    assert 'document' in res.payload


def test_get_report_document_n_decrypt():
    res = Reports().get_report_document('as',
                                        decrypt=False)
    print(res)
    assert 'document' not in res.payload


def test_create_report_schedule():
    res = Reports().create_report_schedule(reportType='GET_FLAT_FILE_OPEN_LISTINGS_DATA', period=Schedules.HOURS_8.value)
    print(res)
    assert res.errors is None
    assert 'reportScheduleId' in res.payload


def test_delete_schedule_by_id():
    res = Reports().delete_report_schedule('5000d4018615')
    print(res)
    assert res.errors is None


def test_get_schedule_by_id_existing_schedule():
    res = Reports().get_report_schedule('5000401d8615')
    print(res)
    assert res.errors is None



from datetime import datetime, timedelta

from sp_api.api import Orders
from sp_api.base import SellingApiException


def test_get_orders():
    try:
        res = Orders().get_orders(CreatedAfter=(datetime.utcnow() - timedelta(days=1)).isoformat())
        print(res.payload)  # json data
    except SellingApiException as ex:
        print(ex)


def test_get_order_items():
    print(Orders().get_order_items('asdf-4229851').payload)


def test_get_order():
    print(Orders().get_order('1asdf1-3654623').payload)



# coding: utf-8

"""
    Selling Partner API for Orders

    The Selling Partner API for Orders helps you programmatically retrieve order information. These APIs let you develop fast, flexible, custom applications in areas like order synchronization, order research, and demand-based decision support tools.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from models.payment_method_detail_item_list import PaymentMethodDetailItemList  # noqa: E501
from swagger_client.rest import ApiException


class TestPaymentMethodDetailItemList(unittest.TestCase):
    """PaymentMethodDetailItemList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPaymentMethodDetailItemList(self):
        """Test PaymentMethodDetailItemList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.payment_method_detail_item_list.PaymentMethodDetailItemList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



from enum import Enum


class Schedules(Enum):
    MINUTES_5 = "PT5M"
    MINUTES_15 = "PT15M"
    MINUTES_30 = "PT30M"
    HOUR_1 = "PT1H"
    HOURS_2 = "PT2H"
    HOURS_4 = "PT4H"
    HOURS_8 = "PT8H"
    HOURS_12 = "PT12H"
    DAY_1 = "P1D"
    DAYS_2 = "P2D"
    DAYS_3 = "P3D"
    HOURS_84 = "PT84H"
    DAYS_7 = "P7D"
    DAYS_14 = "P14D"
    DAYS_15 = "P15D"
    DAYS_18 = "P18D"
    DAYS_30 = "P30D"
    MONTH_1 = "P1M"



from sp_api.api import Notifications
from sp_api.base import SellingApiException, NotificationType


def test_create_destination():
    try:
        res = Notifications().create_destination(name='test', arn='arn')
        print(res)
    except SellingApiException as e:
        print(e)


def test_create_subscription():
    res = Notifications().create_subscription(NotificationType.MFN_ORDER_STATUS_CHANGE, destination_id='dest_id')
    print(res)


def test_delete_subscription():
    res = Notifications().delete_notification_subscription(NotificationType.MFN_ORDER_STATUS_CHANGE, 'subscription_id')
    print(res)


def test_get_subscriptions():
    res = Notifications().get_subscription(NotificationType.REPORT_PROCESSING_FINISHED)
    print(res)


def test_add_subscription():
    res = Notifications().add_subscription(NotificationType.REPORT_PROCESSING_FINISHED)
    print(res)



# coding: utf-8

"""
    Selling Partner API for Reports

    The Selling Partner API for Reports lets you retrieve and manage a variety of reports that can help selling partners manage their businesses.  # noqa: E501

    OpenAPI spec version: 2020-09-04
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from models.report_schedule_list import ReportScheduleList  # noqa: E501
from swagger_client.rest import ApiException


class TestReportScheduleList(unittest.TestCase):
    """ReportScheduleList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testReportScheduleList(self):
        """Test ReportScheduleList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.report_schedule_list.ReportScheduleList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import urllib.parse

from sp_api.api import ProductFees
from sp_api.base import Marketplaces


def test_get_fees_for_sku():
    print(ProductFees().get_product_fees_estimate_for_sku("Foo's Club", 39.32, is_fba=False))



import os


class Credentials:
    def __init__(self, refresh_token):
        self.client_id = os.environ.get('LWA_APP_ID')
        self.client_secret = os.environ.get('LWA_CLIENT_SECRET')
        self.refresh_token = refresh_token or os.environ.get('SP_API_REFRESH_TOKEN')



# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AffordabilityExpenseEvent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amazon_order_id': 'str',
        'posted_date': 'ModelDate',
        'marketplace_id': 'str',
        'transaction_type': 'str',
        'base_expense': 'Currency',
        'tax_type_cgst': 'Currency',
        'tax_type_sgst': 'Currency',
        'tax_type_igst': 'Currency',
        'total_expense': 'Currency'
    }

    attribute_map = {
        'amazon_order_id': 'AmazonOrderId',
        'posted_date': 'PostedDate',
        'marketplace_id': 'MarketplaceId',
        'transaction_type': 'TransactionType',
        'base_expense': 'BaseExpense',
        'tax_type_cgst': 'TaxTypeCGST',
        'tax_type_sgst': 'TaxTypeSGST',
        'tax_type_igst': 'TaxTypeIGST',
        'total_expense': 'TotalExpense'
    }

    def __init__(self, amazon_order_id=None, posted_date=None, marketplace_id=None, transaction_type=None, base_expense=None, tax_type_cgst=None, tax_type_sgst=None, tax_type_igst=None, total_expense=None):  # noqa: E501
        """AffordabilityExpenseEvent - a model defined in Swagger"""  # noqa: E501
        self._amazon_order_id = None
        self._posted_date = None
        self._marketplace_id = None
        self._transaction_type = None
        self._base_expense = None
        self._tax_type_cgst = None
        self._tax_type_sgst = None
        self._tax_type_igst = None
        self._total_expense = None
        self.discriminator = None
        if amazon_order_id is not None:
            self.amazon_order_id = amazon_order_id
        if posted_date is not None:
            self.posted_date = posted_date
        if marketplace_id is not None:
            self.marketplace_id = marketplace_id
        if transaction_type is not None:
            self.transaction_type = transaction_type
        if base_expense is not None:
            self.base_expense = base_expense
        self.tax_type_cgst = tax_type_cgst
        self.tax_type_sgst = tax_type_sgst
        self.tax_type_igst = tax_type_igst
        if total_expense is not None:
            self.total_expense = total_expense

    @property
    def amazon_order_id(self):
        """Gets the amazon_order_id of this AffordabilityExpenseEvent.  # noqa: E501

        An Amazon-defined identifier for an order.  # noqa: E501

        :return: The amazon_order_id of this AffordabilityExpenseEvent.  # noqa: E501
        :rtype: str
        """
        return self._amazon_order_id

    @amazon_order_id.setter
    def amazon_order_id(self, amazon_order_id):
        """Sets the amazon_order_id of this AffordabilityExpenseEvent.

        An Amazon-defined identifier for an order.  # noqa: E501

        :param amazon_order_id: The amazon_order_id of this AffordabilityExpenseEvent.  # noqa: E501
        :type: str
        """

        self._amazon_order_id = amazon_order_id

    @property
    def posted_date(self):
        """Gets the posted_date of this AffordabilityExpenseEvent.  # noqa: E501


        :return: The posted_date of this AffordabilityExpenseEvent.  # noqa: E501
        :rtype: ModelDate
        """
        return self._posted_date

    @posted_date.setter
    def posted_date(self, posted_date):
        """Sets the posted_date of this AffordabilityExpenseEvent.


        :param posted_date: The posted_date of this AffordabilityExpenseEvent.  # noqa: E501
        :type: ModelDate
        """

        self._posted_date = posted_date

    @property
    def marketplace_id(self):
        """Gets the marketplace_id of this AffordabilityExpenseEvent.  # noqa: E501

        An encrypted, Amazon-defined marketplace identifier.  # noqa: E501

        :return: The marketplace_id of this AffordabilityExpenseEvent.  # noqa: E501
        :rtype: str
        """
        return self._marketplace_id

    @marketplace_id.setter
    def marketplace_id(self, marketplace_id):
        """Sets the marketplace_id of this AffordabilityExpenseEvent.

        An encrypted, Amazon-defined marketplace identifier.  # noqa: E501

        :param marketplace_id: The marketplace_id of this AffordabilityExpenseEvent.  # noqa: E501
        :type: str
        """

        self._marketplace_id = marketplace_id

    @property
    def transaction_type(self):
        """Gets the transaction_type of this AffordabilityExpenseEvent.  # noqa: E501

        Indicates the type of transaction.   Possible values:  * Charge - For an affordability promotion expense.  * Refund - For an affordability promotion expense reversal.  # noqa: E501

        :return: The transaction_type of this AffordabilityExpenseEvent.  # noqa: E501
        :rtype: str
        """
        return self._transaction_type

    @transaction_type.setter
    def transaction_type(self, transaction_type):
        """Sets the transaction_type of this AffordabilityExpenseEvent.

        Indicates the type of transaction.   Possible values:  * Charge - For an affordability promotion expense.  * Refund - For an affordability promotion expense reversal.  # noqa: E501

        :param transaction_type: The transaction_type of this AffordabilityExpenseEvent.  # noqa: E501
        :type: str
        """

        self._transaction_type = transaction_type

    @property
    def base_expense(self):
        """Gets the base_expense of this AffordabilityExpenseEvent.  # noqa: E501


        :return: The base_expense of this AffordabilityExpenseEvent.  # noqa: E501
        :rtype: Currency
        """
        return self._base_expense

    @base_expense.setter
    def base_expense(self, base_expense):
        """Sets the base_expense of this AffordabilityExpenseEvent.


        :param base_expense: The base_expense of this AffordabilityExpenseEvent.  # noqa: E501
        :type: Currency
        """

        self._base_expense = base_expense

    @property
    def tax_type_cgst(self):
        """Gets the tax_type_cgst of this AffordabilityExpenseEvent.  # noqa: E501


        :return: The tax_type_cgst of this AffordabilityExpenseEvent.  # noqa: E501
        :rtype: Currency
        """
        return self._tax_type_cgst

    @tax_type_cgst.setter
    def tax_type_cgst(self, tax_type_cgst):
        """Sets the tax_type_cgst of this AffordabilityExpenseEvent.


        :param tax_type_cgst: The tax_type_cgst of this AffordabilityExpenseEvent.  # noqa: E501
        :type: Currency
        """
        if tax_type_cgst is None:
            raise ValueError("Invalid value for `tax_type_cgst`, must not be `None`")  # noqa: E501

        self._tax_type_cgst = tax_type_cgst

    @property
    def tax_type_sgst(self):
        """Gets the tax_type_sgst of this AffordabilityExpenseEvent.  # noqa: E501


        :return: The tax_type_sgst of this AffordabilityExpenseEvent.  # noqa: E501
        :rtype: Currency
        """
        return self._tax_type_sgst

    @tax_type_sgst.setter
    def tax_type_sgst(self, tax_type_sgst):
        """Sets the tax_type_sgst of this AffordabilityExpenseEvent.


        :param tax_type_sgst: The tax_type_sgst of this AffordabilityExpenseEvent.  # noqa: E501
        :type: Currency
        """
        if tax_type_sgst is None:
            raise ValueError("Invalid value for `tax_type_sgst`, must not be `None`")  # noqa: E501

        self._tax_type_sgst = tax_type_sgst

    @property
    def tax_type_igst(self):
        """Gets the tax_type_igst of this AffordabilityExpenseEvent.  # noqa: E501


        :return: The tax_type_igst of this AffordabilityExpenseEvent.  # noqa: E501
        :rtype: Currency
        """
        return self._tax_type_igst

    @tax_type_igst.setter
    def tax_type_igst(self, tax_type_igst):
        """Sets the tax_type_igst of this AffordabilityExpenseEvent.


        :param tax_type_igst: The tax_type_igst of this AffordabilityExpenseEvent.  # noqa: E501
        :type: Currency
        """
        if tax_type_igst is None:
            raise ValueError("Invalid value for `tax_type_igst`, must not be `None`")  # noqa: E501

        self._tax_type_igst = tax_type_igst

    @property
    def total_expense(self):
        """Gets the total_expense of this AffordabilityExpenseEvent.  # noqa: E501


        :return: The total_expense of this AffordabilityExpenseEvent.  # noqa: E501
        :rtype: Currency
        """
        return self._total_expense

    @total_expense.setter
    def total_expense(self, total_expense):
        """Sets the total_expense of this AffordabilityExpenseEvent.


        :param total_expense: The total_expense of this AffordabilityExpenseEvent.  # noqa: E501
        :type: Currency
        """

        self._total_expense = total_expense

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AffordabilityExpenseEvent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AffordabilityExpenseEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Product Fees

    The Selling Partner API for Product Fees lets you programmatically retrieve estimated fees for a product. You can then account for those fees in your pricing.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from models.get_my_fees_estimate_request import GetMyFeesEstimateRequest  # noqa: E501
from swagger_client.rest import ApiException


class TestGetMyFeesEstimateRequest(unittest.TestCase):
    """GetMyFeesEstimateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetMyFeesEstimateRequest(self):
        """Test GetMyFeesEstimateRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.get_my_fees_estimate_request.GetMyFeesEstimateRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Selling Partner API for Product Fees

    The Selling Partner API for Product Fees lets you programmatically retrieve estimated fees for a product. You can then account for those fees in your pricing.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class FeesEstimateError(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'code': 'str',
        'message': 'str',
        'detail': 'FeesEstimateErrorDetail'
    }

    attribute_map = {
        'type': 'Type',
        'code': 'Code',
        'message': 'Message',
        'detail': 'Detail'
    }

    def __init__(self, type=None, code=None, message=None, detail=None):  # noqa: E501
        """FeesEstimateError - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._code = None
        self._message = None
        self._detail = None
        self.discriminator = None
        self.type = type
        self.code = code
        self.message = message
        self.detail = detail

    @property
    def type(self):
        """Gets the type of this FeesEstimateError.  # noqa: E501

        An error type, identifying either the receiver or the sender as the originator of the error.  # noqa: E501

        :return: The type of this FeesEstimateError.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this FeesEstimateError.

        An error type, identifying either the receiver or the sender as the originator of the error.  # noqa: E501

        :param type: The type of this FeesEstimateError.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def code(self):
        """Gets the code of this FeesEstimateError.  # noqa: E501

        An error code that identifies the type of error that occurred.  # noqa: E501

        :return: The code of this FeesEstimateError.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this FeesEstimateError.

        An error code that identifies the type of error that occurred.  # noqa: E501

        :param code: The code of this FeesEstimateError.  # noqa: E501
        :type: str
        """
        if code is None:
            raise ValueError("Invalid value for `code`, must not be `None`")  # noqa: E501

        self._code = code

    @property
    def message(self):
        """Gets the message of this FeesEstimateError.  # noqa: E501

        A message that describes the error condition in a human-readable form.  # noqa: E501

        :return: The message of this FeesEstimateError.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this FeesEstimateError.

        A message that describes the error condition in a human-readable form.  # noqa: E501

        :param message: The message of this FeesEstimateError.  # noqa: E501
        :type: str
        """
        if message is None:
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    @property
    def detail(self):
        """Gets the detail of this FeesEstimateError.  # noqa: E501


        :return: The detail of this FeesEstimateError.  # noqa: E501
        :rtype: FeesEstimateErrorDetail
        """
        return self._detail

    @detail.setter
    def detail(self, detail):
        """Sets the detail of this FeesEstimateError.


        :param detail: The detail of this FeesEstimateError.  # noqa: E501
        :type: FeesEstimateErrorDetail
        """
        if detail is None:
            raise ValueError("Invalid value for `detail`, must not be `None`")  # noqa: E501

        self._detail = detail

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FeesEstimateError, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FeesEstimateError):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from .finances.finances import Finances
from .notifications.notifications import Notifications
from .orders.orders import Orders
from .product_fees.product_fees import ProductFees
from .sellers.sellers import Sellers
from .reports.reports import Reports
from .products.products import Products
from .sales.sales import Sales

__all__ = [
    "Sales",
    "Products",
    "Reports",
    "Orders",
    "Sellers",
    "Notifications",
    "ProductFees",
    "Finances"
]



import urllib.parse

from sp_api.api.products.models.get_pricing_response import GetPricingResponse
from sp_api.base import Client, Marketplaces, sp_endpoint


class Products(Client):
    def __init__(self, marketplace=Marketplaces.US, refresh_token=None):
        super().__init__(marketplace, refresh_token)

    def get_product_pricing_for_skus(self, seller_sku_list, **kwargs):
        """
        Returns pricing information for a seller's offer listings based on seller sku.

        :param seller_sku_list:
        :param kwargs:
        :return:
        """
        return self._create_get_pricing_request(seller_sku_list, 'Sku', **kwargs)

    def get_product_pricing_for_asins(self, asin_list, **kwargs):
        """
        Returns pricing information for a seller's offer listings based on ASIN.

        :param asin_list:
        :param kwargs:
        :return:
        """
        return self._create_get_pricing_request(asin_list, 'Asin', **kwargs)

    @sp_endpoint('/products/pricing/v0/price', method='GET')
    def _create_get_pricing_request(self, item_list, item_type, **kwargs):
        """
        Returns pricing information for a seller's offer listings based on seller SKU or ASIN.

        **Usage Plan:**

        | Rate (requests per second) | Burst |
        | ---- | ---- |
        | 1 | 1 |

        For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.

        :param item_list:
        :param item_type:
        :param kwargs:
        :return:
        """
        return GetPricingResponse(
            **self._request(kwargs.pop('path'),
                            params={**{f"{item_type}s": ','.join(
                                [urllib.parse.quote_plus(s) for s in item_list])},
                                    'ItemType': item_type,
                                    'MarketplaceId': self.marketplace_id}).json())



# coding: utf-8

"""
    Selling Partner API for Reports

    The Selling Partner API for Reports lets you retrieve and manage a variety of reports that can help selling partners manage their businesses.  # noqa: E501

    OpenAPI spec version: 2020-09-04
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ReportDocument(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'report_document_id': 'str',
        'url': 'str',
        'encryption_details': 'ReportDocumentEncryptionDetails',
        'compression_algorithm': 'str'
    }

    attribute_map = {
        'report_document_id': 'reportDocumentId',
        'url': 'url',
        'encryption_details': 'encryptionDetails',
        'compression_algorithm': 'compressionAlgorithm'
    }

    def __init__(self, report_document_id=None, url=None, encryption_details=None, compression_algorithm=None):  # noqa: E501
        """ReportDocument - a model defined in Swagger"""  # noqa: E501
        self._report_document_id = None
        self._url = None
        self._encryption_details = None
        self._compression_algorithm = None
        self.discriminator = None
        self.report_document_id = report_document_id
        self.url = url
        self.encryption_details = encryption_details
        if compression_algorithm is not None:
            self.compression_algorithm = compression_algorithm

    @property
    def report_document_id(self):
        """Gets the report_document_id of this ReportDocument.  # noqa: E501

        The identifier for the report document. This identifier is unique only in combination with a seller ID.  # noqa: E501

        :return: The report_document_id of this ReportDocument.  # noqa: E501
        :rtype: str
        """
        return self._report_document_id

    @report_document_id.setter
    def report_document_id(self, report_document_id):
        """Sets the report_document_id of this ReportDocument.

        The identifier for the report document. This identifier is unique only in combination with a seller ID.  # noqa: E501

        :param report_document_id: The report_document_id of this ReportDocument.  # noqa: E501
        :type: str
        """
        if report_document_id is None:
            raise ValueError("Invalid value for `report_document_id`, must not be `None`")  # noqa: E501

        self._report_document_id = report_document_id

    @property
    def url(self):
        """Gets the url of this ReportDocument.  # noqa: E501

        A presigned URL for the report document. This URL expires after 5 minutes.  # noqa: E501

        :return: The url of this ReportDocument.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this ReportDocument.

        A presigned URL for the report document. This URL expires after 5 minutes.  # noqa: E501

        :param url: The url of this ReportDocument.  # noqa: E501
        :type: str
        """
        if url is None:
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def encryption_details(self):
        """Gets the encryption_details of this ReportDocument.  # noqa: E501


        :return: The encryption_details of this ReportDocument.  # noqa: E501
        :rtype: ReportDocumentEncryptionDetails
        """
        return self._encryption_details

    @encryption_details.setter
    def encryption_details(self, encryption_details):
        """Sets the encryption_details of this ReportDocument.


        :param encryption_details: The encryption_details of this ReportDocument.  # noqa: E501
        :type: ReportDocumentEncryptionDetails
        """
        if encryption_details is None:
            raise ValueError("Invalid value for `encryption_details`, must not be `None`")  # noqa: E501

        self._encryption_details = encryption_details

    @property
    def compression_algorithm(self):
        """Gets the compression_algorithm of this ReportDocument.  # noqa: E501

        If present, the report document contents have been compressed with the provided algorithm.  # noqa: E501

        :return: The compression_algorithm of this ReportDocument.  # noqa: E501
        :rtype: str
        """
        return self._compression_algorithm

    @compression_algorithm.setter
    def compression_algorithm(self, compression_algorithm):
        """Sets the compression_algorithm of this ReportDocument.

        If present, the report document contents have been compressed with the provided algorithm.  # noqa: E501

        :param compression_algorithm: The compression_algorithm of this ReportDocument.  # noqa: E501
        :type: str
        """
        allowed_values = ["GZIP"]  # noqa: E501
        if compression_algorithm not in allowed_values:
            raise ValueError(
                "Invalid value for `compression_algorithm` ({0}), must be one of {1}"  # noqa: E501
                .format(compression_algorithm, allowed_values)
            )

        self._compression_algorithm = compression_algorithm

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ReportDocument, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReportDocument):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Notifications

    The Selling Partner API for Notifications lets you subscribe to notifications that are relevant to a selling partner's business. Using this API you can create a destination to receive notifications, subscribe to notifications, delete notification subscriptions, and more.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Subscription(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'subscription_id': 'str',
        'payload_version': 'str',
        'destination_id': 'str'
    }

    attribute_map = {
        'subscription_id': 'subscriptionId',
        'payload_version': 'payloadVersion',
        'destination_id': 'destinationId'
    }

    def __init__(self, subscription_id=None, payload_version=None, destination_id=None):  # noqa: E501
        """Subscription - a model defined in Swagger"""  # noqa: E501
        self._subscription_id = None
        self._payload_version = None
        self._destination_id = None
        self.discriminator = None
        self.subscription_id = subscription_id
        self.payload_version = payload_version
        self.destination_id = destination_id

    @property
    def subscription_id(self):
        """Gets the subscription_id of this Subscription.  # noqa: E501

        The subscription identifier generated when the subscription is created.  # noqa: E501

        :return: The subscription_id of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._subscription_id

    @subscription_id.setter
    def subscription_id(self, subscription_id):
        """Sets the subscription_id of this Subscription.

        The subscription identifier generated when the subscription is created.  # noqa: E501

        :param subscription_id: The subscription_id of this Subscription.  # noqa: E501
        :type: str
        """
        if subscription_id is None:
            raise ValueError("Invalid value for `subscription_id`, must not be `None`")  # noqa: E501

        self._subscription_id = subscription_id

    @property
    def payload_version(self):
        """Gets the payload_version of this Subscription.  # noqa: E501

        The version of the payload object to be used in the notification.  # noqa: E501

        :return: The payload_version of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._payload_version

    @payload_version.setter
    def payload_version(self, payload_version):
        """Sets the payload_version of this Subscription.

        The version of the payload object to be used in the notification.  # noqa: E501

        :param payload_version: The payload_version of this Subscription.  # noqa: E501
        :type: str
        """
        if payload_version is None:
            raise ValueError("Invalid value for `payload_version`, must not be `None`")  # noqa: E501

        self._payload_version = payload_version

    @property
    def destination_id(self):
        """Gets the destination_id of this Subscription.  # noqa: E501

        The identifier for the destination where notifications will be delivered.  # noqa: E501

        :return: The destination_id of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._destination_id

    @destination_id.setter
    def destination_id(self, destination_id):
        """Sets the destination_id of this Subscription.

        The identifier for the destination where notifications will be delivered.  # noqa: E501

        :param destination_id: The destination_id of this Subscription.  # noqa: E501
        :type: str
        """
        if destination_id is None:
            raise ValueError("Invalid value for `destination_id`, must not be `None`")  # noqa: E501

        self._destination_id = destination_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Subscription, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Subscription):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from setuptools import setup

setup(
    name='python-amazon-sp-api',
    version='0.0.16',
    install_requires=[
        "requests",
        "six~=1.15.0",
        "boto3~=1.16.39",
        "cachetools~=4.2.0",
        "pycryptodome",
        "pytz"
    ],
    packages=['tests', 'tests.api', 'tests.api.orders', 'tests.api.sellers', 'tests.api.finances',
              'tests.api.product_fees', 'tests.api.notifications', 'tests.api.reports', 'tests.client', 'sp_api',
              'sp_api.api',
              'sp_api.api.orders', 'sp_api.api.orders.models', 'sp_api.api.sellers', 'sp_api.api.sellers.models',
              'sp_api.api.finances', 'sp_api.api.finances.models', 'sp_api.api.product_fees',
              'sp_api.api.product_fees.models', 'sp_api.api.products', 'sp_api.api.products.models',
              'sp_api.api.sales', 'sp_api.api.sales.models',
              'sp_api.api.notifications', 'sp_api.api.notifications.models', 'sp_api.api.reports',
              'sp_api.api.reports.models', 'sp_api.auth', 'sp_api.base'],
    url='https://github.com/saleweaver/python-amazon-sp-api',
    license='mit',
    author='Michael Primke',
    author_email='info@saleweaver.com',
    description='python wrapper for amazon selling partner api'
)



# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from models.shipment_event import ShipmentEvent  # noqa: E501
from swagger_client.rest import ApiException


class TestShipmentEvent(unittest.TestCase):
    """ShipmentEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testShipmentEvent(self):
        """Test ShipmentEvent"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.shipment_event.ShipmentEvent()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
